@@ -17,8 +17,10 @@
 #ifndef BZF_BILLBOARD_SCENE_NODE_H
 #define BZF_BILLBOARD_SCENE_NODE_H
 
-#include "common.h"
+// Inherits from
 #include "SceneNode.h"
+
+// Commen headers
 #include "OpenGLLight.h"
 
 class BillboardSceneNode : public SceneNode
