@@ -17,11 +17,13 @@
 #ifndef BZF_BOLT_SCENE_NODE_H
 #define BZF_BOLT_SCENE_NODE_H
 
-#include "common.h"
-#include "ShotSceneNode.h"
+// Inherits from
+#include "SceneNode.h"
+
+// Common headers
 #include "OpenGLLight.h"
 
-class BoltSceneNode : public ShotSceneNode
+class BoltSceneNode : public SceneNode
 {
 public:
     BoltSceneNode(const GLfloat pos[3], const GLfloat vel[3], bool super);
@@ -48,7 +50,7 @@ public:
         invisible = _invisible;
     }
 
-    void        move(const GLfloat pos[3], const GLfloat forward[3]);
+    virtual void move(const GLfloat pos[3], const GLfloat forward[3]);
     void        addLight(SceneRenderer&);
 
     void        notifyStyleChange();
