@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2017 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -17,18 +17,20 @@
 #include <string>
 #include <vector>
 
-class CacheManager {
-  public:
+class CacheManager
+{
+public:
     CacheManager();
     ~CacheManager();
 
-    typedef struct {
-      std::string url;
-      time_t usedDate;
-      std::string name;
-      int size;
-      time_t date;
-      std::string key;
+    typedef struct
+    {
+        std::string url;
+        time_t usedDate;
+        std::string name;
+        int size;
+        time_t date;
+        std::string key;
     } CacheRecord;
 
     bool isCacheFileType(const std::string &name) const;
@@ -44,11 +46,12 @@ class CacheManager {
 
     void limitCacheSize();
 
-  private:
+private:
     int findRecord(const std::string& url);
 
-  private:
+private:
     std::string indexName;
+    std::string getIndexPath();
     std::vector<CacheRecord> records;
 };
 
