@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2017 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -11,11 +11,11 @@
  */
 
 /* ConeObstacle:
- *	Encapsulates a cone in the game environment.
+ *  Encapsulates a cone in the game environment.
  */
 
-#ifndef	BZF_CONE_OBSTACLE_H
-#define	BZF_CONE_OBSTACLE_H
+#ifndef BZF_CONE_OBSTACLE_H
+#define BZF_CONE_OBSTACLE_H
 
 #include "common.h"
 #include <string>
@@ -25,24 +25,26 @@
 #include "BzMaterial.h"
 
 
-class ConeObstacle : public Obstacle {
-  public:
+class ConeObstacle : public Obstacle
+{
+public:
 
-    enum {
-      Edge,
-      Bottom,
-      StartFace,
-      EndFace,
-      MaterialCount
+    enum
+    {
+        Edge,
+        Bottom,
+        StartFace,
+        EndFace,
+        MaterialCount
     };
 
     ConeObstacle();
     ConeObstacle(const MeshTransform& transform,
-		 const float* _pos, const float* _size,
-		 float _rotation, float _angle,
-		 const float _texsize[2], bool _useNormals,
-		 int _divisions, const BzMaterial* mats[MaterialCount],
-		 int physics, bool bounce, bool drive, bool shoot, bool ricochet);
+                 const float* _pos, const float* _size,
+                 float _rotation, float _angle,
+                 const float _texsize[2], bool _useNormals,
+                 int _divisions, const BzMaterial* mats[MaterialCount],
+                 int physics, bool bounce, bool drive, bool shoot, bool ricochet);
     ~ConeObstacle();
 
     Obstacle* copyWithTransform(const MeshTransform&) const;
@@ -59,18 +61,18 @@ class ConeObstacle : public Obstacle {
 
     bool inCylinder(const float* p, float radius, float height) const;
     bool inBox(const float* p, float angle,
-	       float halfWidth, float halfBreadth, float height) const;
+               float halfWidth, float halfBreadth, float height) const;
     bool inMovingBox(const float* oldP, float oldAngle,
-		     const float *newP, float newAngle,
-		     float halfWidth, float halfBreadth, float height) const;
+                     const float *newP, float newAngle,
+                     float halfWidth, float halfBreadth, float height) const;
     bool isCrossing(const float* p, float angle,
-		    float halfWidth, float halfBreadth, float height,
-		    float* plane) const;
+                    float halfWidth, float halfBreadth, float height,
+                    float* plane) const;
 
     bool getHitNormal(const float* pos1, float azimuth1,
-		      const float* pos2, float azimuth2,
-		      float halfWidth, float halfBreadth,
-		      float height, float* normal) const;
+                      const float* pos2, float azimuth2,
+                      float halfWidth, float halfBreadth,
+                      float height, float* normal) const;
 
     int packSize() const;
     void *pack(void*) const;
@@ -78,10 +80,10 @@ class ConeObstacle : public Obstacle {
 
     void print(std::ostream& out, const std::string& indent) const;
 
-  private:
+private:
     void finalize();
 
-  private:
+private:
     static const char* typeName;
 
     MeshTransform transform;
@@ -99,8 +101,8 @@ class ConeObstacle : public Obstacle {
 
 // Local Variables: ***
 // mode: C++ ***
-// tab-width: 8 ***
-// c-basic-offset: 2 ***
-// indent-tabs-mode: t ***
+// tab-width: 4 ***
+// c-basic-offset: 4 ***
+// indent-tabs-mode: nil ***
 // End: ***
-// ex: shiftwidth=2 tabstop=8
+// ex: shiftwidth=4 tabstop=4
