@@ -18,7 +18,7 @@
 #ifndef BZF_FLAG_WARP_SCENE_NODE_H
 #define BZF_FLAG_WARP_SCENE_NODE_H
 
-#include "common.h"
+// Inherits
 #include "SceneNode.h"
 
 class FlagWarpSceneNode : public SceneNode
