@@ -19,10 +19,11 @@
 #ifndef BZF_MESH_SCENE_NODE_H
 #define BZF_MESH_SCENE_NODE_H
 
-#include "common.h"
-#include "bzfgl.h"
+// Inherits
 #include "SceneNode.h"
 
+// Common headers
+#include "bzfgl.h"
 //
 // NOTES:
 //
@@ -62,7 +63,6 @@ public:
     void getRenderNodes(std::vector<RenderSet>& rnodes);
 
     void makeXFormList();
-    void freeXFormList();
     static void initContext(void* data);
     static void freeContext(void* data);
 
@@ -79,7 +79,7 @@ private:
     bool animRepos;
 
     // transform display list
-    GLuint xformList;
+    GLfloat xformMatrix[16];
 
     struct MeshMaterial
     {
@@ -125,7 +125,6 @@ private:
     void updateMaterial(MeshMaterial* mat);
     const BzMaterial* convertMaterial(const BzMaterial* bzmat);
     int calcNormalLod(const ViewFrustum&);
-    int calcShadowLod(const ViewFrustum&);
     int calcRadarLod();
 
     friend class MeshSceneNodeMgr;
