@@ -18,7 +18,7 @@
 #ifndef BZF_POLY_WALL_SCENE_NODE_H
 #define BZF_POLY_WALL_SCENE_NODE_H
 
-#include "common.h"
+// Inherits from
 #include "WallSceneNode.h"
 
 class PolyWallSceneNode : public WallSceneNode
