@@ -17,7 +17,7 @@
 #ifndef BZF_SPHERE_SCENE_NODE_H
 #define BZF_SPHERE_SCENE_NODE_H
 
-#include "common.h"
+// Inherits from
 #include "SceneNode.h"
 
 
@@ -62,10 +62,6 @@ public:
     SphereLodSceneNode(const GLfloat pos[3], GLfloat radius);
     ~SphereLodSceneNode();
 
-    void setColor(GLfloat r, GLfloat g, GLfloat b, GLfloat a = 1.0f);
-    void setColor(const GLfloat* rgba);
-    void move(const GLfloat pos[3], GLfloat radius);
-
     void setShockWave(bool value);
 
     // this node just won't split
@@ -173,11 +169,6 @@ public:
     SphereBspSceneNode(const GLfloat pos[3], GLfloat radius);
     ~SphereBspSceneNode();
 
-    void        setColor(GLfloat r, GLfloat g,
-                         GLfloat b, GLfloat a = 1.0f);
-    void        setColor(const GLfloat* rgba);
-    void        move(const GLfloat pos[3], GLfloat radius);
-
     void        addRenderNodes(SceneRenderer&);
     void        addShadowNodes(SceneRenderer&);
 
