@@ -17,10 +17,12 @@
 #ifndef BZF_VIEW_FRUSTUM_H
 #define BZF_VIEW_FRUSTUM_H
 
-#include "common.h"
-#include "bzfgl.h"
+// inherits from
 #include "Frustum.h"
 
+// Common headers
+#include "bzfgl.h"
+
 // FIXME -- will need a means for off center projections for
 //  looking through teleporters
 
