@@ -39,9 +39,14 @@
 #define strcasecmp stricmp
 #endif
 #else
+#ifdef __clang__
+#define BZF_API __attribute__((visibility("default")))
+#define BZF_PLUGIN_CALL extern "C" __attribute__((visibility("default")))
+#else
 #define BZF_API
 #define BZF_PLUGIN_CALL extern "C"
 #endif
+#endif
 
 /* Provide a means to deprecate API functions to discourage their use
  * in the future
@@ -337,6 +342,7 @@ typedef enum
     bz_eServerShotFiredEvent,
     bz_ePermissionModificationEvent,
     bz_eAllowServerShotFiredEvent,
+    bz_ePlayerDeathFinalizedEvent,
     bz_eLastEvent    //this is never used as an event, just show it's the last one
 } bz_eEventType;
 
@@ -1895,6 +1901,7 @@ BZF_API bool bz_moveFlag ( int flag, float pos[3] );
 BZF_API int bz_getPlayerFlagID ( int playerID );
 BZF_API int bz_flagPlayer ( int flag );
 BZF_API bool bz_getFlagPosition ( int flag, float* pos );
+BZF_API bool bz_getNearestFlagSafetyZone(int flag, float *pos);
 
 
 // world
@@ -2001,6 +2008,8 @@ private:
 };
 
 BZF_API void bz_getRandomPoint ( bz_CustomZoneObject *obj, float *randomPos );
+BZF_API bool bz_getSpawnPointWithin ( bz_CustomZoneObject *obj, float randomPos[3] );
+BZF_API bool bz_isWithinWorldBoundaries ( float pos[3] );
 
 class bz_CustomMapObjectHandler
 {
