@@ -9,6 +9,10 @@
  * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
  * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
+
+#ifndef __BZSIGNAL_H__
+#define __BZSIGNAL_H__
+
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -32,6 +36,8 @@ SIG_PF bzSignal(int signo, SIG_PF func);
 }
 #endif
 
+#endif // __BZSIGNAL_H__
+
 /*
  * Local Variables: ***
  * mode: C++ ***
