@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2017 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -21,21 +21,22 @@
 
 /** This struct stores information about a player that is relevant to
     bzadmin. */
-struct PlayerInfo {
-  PlayerInfo(): wins(), losses(), tks(),
-    isRegistered(), isVerified(), isAdmin() {}
-  PlayerInfo(const std::string& n) : name(n),
-    wins(), losses(), tks(), isRegistered(),
-    isVerified(), isAdmin() {}
-  std::string name;
-  std::string ip;
-  TeamColor team;
-  int wins;
-  int losses;
-  int tks;
-  bool isRegistered;
-  bool isVerified;
-  bool isAdmin;
+struct PlayerInfo
+{
+    PlayerInfo(): wins(), losses(), tks(),
+        isRegistered(), isVerified(), isAdmin() {}
+    PlayerInfo(const std::string& n) : name(n),
+        wins(), losses(), tks(), isRegistered(),
+        isVerified(), isAdmin() {}
+    std::string name;
+    std::string ip;
+    TeamColor team;
+    int wins;
+    int losses;
+    int tks;
+    bool isRegistered;
+    bool isVerified;
+    bool isAdmin;
 };
 
 
@@ -46,8 +47,8 @@ typedef std::map<PlayerId, PlayerInfo> PlayerIdMap;
 
 // Local Variables: ***
 // mode: C++ ***
-// tab-width: 8 ***
-// c-basic-offset: 2 ***
-// indent-tabs-mode: t ***
+// tab-width: 4 ***
+// c-basic-offset: 4 ***
+// indent-tabs-mode: nil ***
 // End: ***
-// ex: shiftwidth=2 tabstop=8
+// ex: shiftwidth=4 tabstop=4
