@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2018 Tim Riker
+ * Copyright (c) 1993-2019 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -20,11 +20,10 @@
 #  include <stdlib.h>
 #  include <wincon.h>
 #else
+#  include <cstring>
+#  include <unistd.h>
 #  include <sys/types.h>
 #  include <sys/select.h>
-#  ifdef HAVE_STRING_H
-#    include <string.h> // on Solaris FD_ZERO() is a macro that uses memset()
-#  endif
 #endif
 
 /* implementation headers */
