@@ -60,12 +60,8 @@ const GLfloat       BackgroundRenderer::defaultGroundColorInv[4][4] =
     { 1.00f, 1.00f, 1.00f, 1.0f },
     { 1.00f, 1.00f, 1.00f, 1.0f }
 };
-const GLfloat       BackgroundRenderer::receiverColor[3] =
-{ 0.3f, 0.55f, 0.3f };
-const GLfloat       BackgroundRenderer::receiverColorInv[3] =
-{ 0.55f, 0.3f, 0.55f };
 
-BackgroundRenderer::BackgroundRenderer(const SceneRenderer&) :
+BackgroundRenderer::BackgroundRenderer() :
     blank(false),
     invert(false),
     style(0),
@@ -129,7 +125,7 @@ BackgroundRenderer::BackgroundRenderer(const SceneRenderer&) :
     // sun shadow stuff
     gstate.reset();
     gstate.setStipple(0.5f);
-    gstate.setCulling((GLenum)GL_NONE);
+    gstate.disableCulling();
     sunShadowsGState = gstate.getState();
 
     /* useMoonTexture = BZDBCache::texture && (BZDB.eval("useQuality")>2);
@@ -796,12 +792,10 @@ void BackgroundRenderer::setupSkybox()
         bzmats[i]->setReference();
 
     // setup the wrap mode
-    skyboxWrapMode = GL_CLAMP;
-#ifdef GL_VERSION_1_2
-    const char* extStr = (const char*) glGetString(GL_EXTENSIONS);
-    if (strstr(extStr, "GL_EXT_texture_edge_clamp") != NULL)
+    if (GLEW_EXT_texture_edge_clamp)
         skyboxWrapMode = GL_CLAMP_TO_EDGE;
-#endif
+    else
+        skyboxWrapMode = GL_CLAMP;
 
     // setup the corner colors
     const int cornerFaces[8][3] =
@@ -1067,11 +1061,7 @@ void BackgroundRenderer::drawSky(SceneRenderer& renderer, bool mirror)
     const bool useClipPlane = (mirror && (doSkybox || BZDBCache::drawCelestial));
 
     if (useClipPlane)
-    {
         glEnable(GL_CLIP_PLANE0);
-        const GLdouble plane[4] = {0.0, 0.0, +1.0, 0.0};
-        glClipPlane(GL_CLIP_PLANE0, plane);
-    }
 
     if (doSkybox)
         drawSkybox();
