@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2017 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -27,12 +27,13 @@
 typedef std::deque<std::string> MessageQueue;
 
 extern MessageQueue messageHistory;
-extern unsigned int	messageHistoryIndex;
+extern unsigned int messageHistoryIndex;
 
-class ComposeDefaultKey : public HUDuiDefaultKey {
+class ComposeDefaultKey : public HUDuiDefaultKey
+{
 public:
-  bool		keyPress(const BzfKeyEvent&);
-  bool		keyRelease(const BzfKeyEvent&);
+    bool      keyPress(const BzfKeyEvent&);
+    bool      keyRelease(const BzfKeyEvent&);
 };
 
 
@@ -40,8 +41,8 @@ public:
 
 // Local Variables: ***
 // mode: C++ ***
-// tab-width: 8 ***
-// c-basic-offset: 2 ***
-// indent-tabs-mode: t ***
+// tab-width: 4 ***
+// c-basic-offset: 4 ***
+// indent-tabs-mode: nil ***
 // End: ***
-// ex: shiftwidth=2 tabstop=8
+// ex: shiftwidth=4 tabstop=4
