@@ -327,14 +327,12 @@ void            ControlPanel::render(SceneRenderer& _renderer)
     int i, j;
     const int x = window.getOriginX();
     const int y = window.getOriginY();
-    const int w = window.getWidth();
     const int tabStyle = BZDB.evalInt("showtabs");
     const bool showTabs = (tabStyle > 0);
     tabsOnRight = (tabStyle == 2);
 
     glMatrixMode(GL_PROJECTION);
-    glLoadIdentity();
-    glOrtho(0.0, (double)w, 0.0, window.getHeight(), -1.0, 1.0);
+    window.setProjectionPlay();
     glMatrixMode(GL_MODELVIEW);
     glPushMatrix();
     glLoadIdentity();
@@ -362,17 +360,23 @@ void            ControlPanel::render(SceneRenderer& _renderer)
         if (BZDBCache::blend && _renderer.getPanelOpacity() < 1.0f)
             glEnable(GL_BLEND);
 
+        GLint x1 = messageAreaPixels[0];
+        GLint x2 = x1 + messageAreaPixels[2];
+        GLint y1 = messageAreaPixels[1];
+        GLint y2 = y1 + messageAreaPixels[3];
         // clear the background
         glColor4f(0.0f, 0.0f, 0.0f, _renderer.getPanelOpacity());
-        glRecti(messageAreaPixels[0] - 1, // clear an extra pixel column to simplify fuzzy float stuff later
-                messageAreaPixels[1],
-                messageAreaPixels[0] + messageAreaPixels[2],
-                messageAreaPixels[1] + messageAreaPixels[3]);
+        // clear an extra pixel column to simplify fuzzy float stuff later
+        glRecti(x1 - 1, y1, x2, y2);
 
         // display tabs for chat sections
         if (showTabs)
         {
-            long int drawnTabWidth = 0;
+            if (tabsOnRight)
+                // draw the tabs on the right side
+                x1 = x2 - totalTabWidth;
+            y2 += ay;
+            y1 = y2 - int(lineHeight + 4);
             for (unsigned int tab = 0; tab < tabs->size(); tab++)
             {
 
@@ -382,24 +386,9 @@ void            ControlPanel::render(SceneRenderer& _renderer)
                 else
                     glColor4f(0.10f, 0.10f, 0.10f, _renderer.getPanelOpacity());
 
-                if (tabsOnRight)
-                {
-                    // draw the tabs on the right side
-                    glRecti(messageAreaPixels[0] + messageAreaPixels[2] - totalTabWidth + drawnTabWidth,
-                            messageAreaPixels[1] + messageAreaPixels[3] - int(lineHeight + 4) + ay,
-                            messageAreaPixels[0] + messageAreaPixels[2] - totalTabWidth + drawnTabWidth + int(
-                                tabTextWidth[tab]), //+ drawnTabWidth + int(tabTextWidth[tab]),
-                            messageAreaPixels[1] + messageAreaPixels[3] + ay);
-                }
-                else
-                {
-                    // draw the tabs on the left side
-                    glRecti(messageAreaPixels[0] + drawnTabWidth,
-                            messageAreaPixels[1] + messageAreaPixels[3] - int(lineHeight + 4) + ay,
-                            messageAreaPixels[0] + drawnTabWidth + int(tabTextWidth[tab]),
-                            messageAreaPixels[1] + messageAreaPixels[3] + ay);
-                }
-                drawnTabWidth += long(tabTextWidth[tab]);
+                x2 = x1 + int(tabTextWidth[tab]);
+                glRecti(x1, y1, x2, y2);
+                x1 = x2;
             } // end iteration over tabs
         }
 
@@ -652,46 +641,6 @@ void            ControlPanel::render(SceneRenderer& _renderer)
     }
     glEnd();
 
-    if (0)
-    {
-        // some engines miss the corners
-        glBegin(GL_POINTS);
-        {
-            glVertex2f((float) (x + messageAreaPixels[0] - 1),
-                       (float) (y + messageAreaPixels[1] - 1));
-            glVertex2f((float) (x + messageAreaPixels[0] + messageAreaPixels[2]),
-                       (float) (y + messageAreaPixels[1] - 1));
-            glVertex2f((float) (x + messageAreaPixels[0] + messageAreaPixels[2]),
-                       (float) (y + messageAreaPixels[1] + messageAreaPixels[3]));
-            glVertex2f((float) (x + messageAreaPixels[0] - 1),
-                       (float) (y + messageAreaPixels[1] + messageAreaPixels[3]));
-            long int tabPosition = 0;
-            for (int tab = 0; tab < (int)tabs->size(); tab++)
-            {
-                if (messageMode == MessageModes(tab))
-                {
-                    if (tabsOnRight)
-                    {
-                        glVertex2f((float) (x + messageAreaPixels[0] + messageAreaPixels[2] - totalTabWidth + tabPosition),
-                                   (float) (y + messageAreaPixels[1] + messageAreaPixels[3] + ay));
-                        glVertex2f((float) (x + messageAreaPixels[0] + messageAreaPixels[2] - totalTabWidth + tabPosition + long(
-                                                tabTextWidth[tab])),
-                                   (float) (y + messageAreaPixels[1] + messageAreaPixels[3] + ay));
-                    }
-                    else
-                    {
-                        glVertex2f((float) (x + messageAreaPixels[0] + tabPosition),
-                                   (float) (y + messageAreaPixels[1] + messageAreaPixels[3] + ay));
-                        glVertex2f((float) (x + messageAreaPixels[0] + tabPosition + long(tabTextWidth[tab])),
-                                   (float) (y + messageAreaPixels[1] + messageAreaPixels[3] + ay));
-                    }
-                }
-                tabPosition += long(tabTextWidth[tab]);
-            }
-        }
-        glEnd();
-    }
-
     if (BZDBCache::blend)
         glDisable(GL_BLEND);
 
