@@ -43,6 +43,109 @@ DisplayMenu::DisplayMenu() : formatMenu(NULL)
     label->setString("Display Settings");
     listHUD.push_back(label);
 
+    option = new HUDuiList;
+    option->setFontFace(fontFace);
+    option->setLabel("Quality:");
+    option->setCallback(callback, "6");
+    options = &option->getList();
+    options->push_back(std::string("Low"));
+    options->push_back(std::string("Medium"));
+    options->push_back(std::string("High"));
+    options->push_back(std::string("Experimental"));
+    option->update();
+    listHUD.push_back(option);
+
+    option = new HUDuiList;
+    option->setFontFace(fontFace);
+    option->setLabel("Texturing:");
+    option->setCallback(callback, "5");
+    options = &option->getList();
+    options->push_back(std::string("Off"));
+    options->push_back(std::string("Nearest"));
+    options->push_back(std::string("Linear"));
+    options->push_back(std::string("Nearest Mipmap Nearest"));
+    options->push_back(std::string("Linear Mipmap Nearest"));
+    options->push_back(std::string("Nearest Mipmap Linear"));
+    options->push_back(std::string("Linear Mipmap Linear"));
+    option->update();
+    listHUD.push_back(option);
+
+    option = new HUDuiList;
+    option->setFontFace(fontFace);
+    option->setLabel("Lighting:");
+    option->setCallback(callback, "4");
+    options = &option->getList();
+    options->push_back(std::string("None"));
+    options->push_back(std::string("Fast"));
+    options->push_back(std::string("Best"));
+    option->update();
+    listHUD.push_back(option);
+
+    option = new HUDuiList;
+    option->setFontFace(fontFace);
+    option->setLabel("Shadows:");
+    option->setCallback(callback, "7");
+    options = &option->getList();
+    options->push_back(std::string("Off"));
+    options->push_back(std::string("Stipple"));
+    options->push_back(std::string("Stencil"));
+    option->update();
+    listHUD.push_back(option);
+
+
+    if (OpenGLGState::getMaxSamples() > 1)
+    {
+        option = new HUDuiList;
+        option->setFontFace(fontFace);
+        option->setLabel("Anti Aliasing:");
+        option->setCallback(callback, "m");
+        options = &option->getList();
+        options->push_back(std::string("Off"));
+        for (int i = 2; i <= OpenGLGState::getMaxSamples(); i=i*2)
+        {
+            char msaaText[11];
+            snprintf(msaaText, sizeof(msaaText), "%i", i);
+            options->push_back(std::string(msaaText) + "x MSAA");
+        }
+        option->update();
+        listHUD.push_back(option);
+    }
+
+    if (OpenGLGState::hasAnisotropicFiltering)
+    {
+        static GLint maxAnisotropy = 1;
+        glGetIntegerv(GL_MAX_TEXTURE_MAX_ANISOTROPY_EXT, &maxAnisotropy);
+        if (maxAnisotropy > 1)
+        {
+            option = new HUDuiList;
+            option->setFontFace(fontFace);
+            option->setLabel("Anisotropic:");
+            option->setCallback(callback, "A");
+            options = &option->getList();
+            options->push_back(std::string("Off"));
+            for (int i = 2; i <= maxAnisotropy; i=i*2)
+            {
+                char buffer[16];
+                snprintf(buffer, sizeof(buffer), "%i/%i", i, maxAnisotropy);
+                options->push_back(std::string(buffer));
+            }
+            option->update();
+            listHUD.push_back(option);
+        }
+    }
+
+    option = new HUDuiList;
+    option->setFontFace(fontFace);
+    option->setLabel("AntiFlicker:");
+    option->setCallback(callback, "R");
+    options = &option->getList();
+    options->push_back(std::string("Off"));
+    options->push_back(std::string("On"));
+    option->update();
+    listHUD.push_back(option);
+
+
+
     option = new HUDuiList;
     option->setFontFace(fontFace);
     option->setLabel("Dithering:");
@@ -73,105 +176,46 @@ DisplayMenu::DisplayMenu() : formatMenu(NULL)
     option->update();
     listHUD.push_back(option);
 
-    option = new HUDuiList;
-    option->setFontFace(fontFace);
-    option->setLabel("Lighting:");
-    option->setCallback(callback, "4");
-    options = &option->getList();
-    options->push_back(std::string("None"));
-    options->push_back(std::string("Fast"));
-    options->push_back(std::string("Best"));
-    option->update();
-    listHUD.push_back(option);
 
-    option = new HUDuiList;
-    option->setFontFace(fontFace);
-    option->setLabel("Texturing:");
-    option->setCallback(callback, "5");
-    options = &option->getList();
-    options->push_back(std::string("Off"));
-    options->push_back(std::string("Nearest"));
-    options->push_back(std::string("Linear"));
-    options->push_back(std::string("Nearest Mipmap Nearest"));
-    options->push_back(std::string("Linear Mipmap Nearest"));
-    options->push_back(std::string("Nearest Mipmap Linear"));
-    options->push_back(std::string("Linear Mipmap Linear"));
-    option->update();
-    listHUD.push_back(option);
 
-    option = new HUDuiList;
-    option->setFontFace(fontFace);
-    option->setLabel("AntiFlicker:");
-    option->setCallback(callback, "R");
-    options = &option->getList();
-    options->push_back(std::string("Off"));
-    options->push_back(std::string("On"));
-    option->update();
-    listHUD.push_back(option);
-
-    if (OpenGLGState::hasAnisotropicFiltering)
+    if (((BzfWindow*)getMainWindow()->getWindow())->hasGammaControl())
     {
-        static GLint maxAnisotropy = 1;
-        glGetIntegerv(GL_MAX_TEXTURE_MAX_ANISOTROPY_EXT, &maxAnisotropy);
-        if (maxAnisotropy > 1)
-        {
-            option = new HUDuiList;
-            option->setFontFace(fontFace);
-            option->setLabel("Anisotropic:");
-            option->setCallback(callback, "A");
-            options = &option->getList();
-            options->push_back(std::string("Off"));
-            for (int i = 1; i < maxAnisotropy; i++)
-            {
-                char buffer[16];
-                snprintf(buffer, 16, "%i/%i", i + 1, maxAnisotropy);
-                options->push_back(std::string(buffer));
-            }
-            option->update();
-            listHUD.push_back(option);
-        }
+        option = new HUDuiList;
+        option->setFontFace(fontFace);
+        option->setLabel("Brightness:");
+        option->setCallback(callback, "g");
+        option->createSlider(15);
+        option->update();
+        listHUD.push_back(option);
     }
 
     option = new HUDuiList;
     option->setFontFace(fontFace);
-    option->setLabel("Quality:");
-    option->setCallback(callback, "6");
+
+#if (defined(HAVE_SDL) && !defined(HAVE_SDL2))  // only SDL 2 can make live changes
+    option->setLabel("(restart required) Energy Saver:");
+#else
+    option->setLabel("Energy Saver:");
+#endif
+    option->setCallback(callback, "s");
     options = &option->getList();
-    options->push_back(std::string("Low"));
-    options->push_back(std::string("Medium"));
-    options->push_back(std::string("High"));
-    options->push_back(std::string("Experimental"));
+    options->push_back(std::string("Off"));
+    options->push_back(std::string("FPS Limit"));
+    if (getMainWindow()->getWindow()->hasVerticalSync())
+        options->push_back(std::string("Vertical Sync"));
     option->update();
     listHUD.push_back(option);
 
-    option = new HUDuiList;
-    option->setFontFace(fontFace);
-    option->setLabel("Shadows:");
-    option->setCallback(callback, "7");
-    options = &option->getList();
-    options->push_back(std::string("Off"));
-    options->push_back(std::string("Stipple"));
-    options->push_back(std::string("Stencil"));
-    option->update();
-    listHUD.push_back(option);
+
 
 #if defined(DEBUG_RENDERING)
-    option = new HUDuiList;
-    option->setFontFace(fontFace);
-    option->setLabel("Hidden Line:");
-    option->setCallback(callback, "a");
-    options = &option->getList();
-    options->push_back(std::string("Off"));
-    options->push_back(std::string("On"));
-    option->update();
-    listHUD.push_back(option);
-
     option = new HUDuiList;
     option->setFontFace(fontFace);
     option->setLabel("Wireframe:");
     option->setCallback(callback, "b");
     options = &option->getList();
     options->push_back(std::string("Off"));
+    options->push_back(std::string("Hidden Line"));
     options->push_back(std::string("On"));
     option->update();
     listHUD.push_back(option);
@@ -207,51 +251,7 @@ DisplayMenu::DisplayMenu() : formatMenu(NULL)
     listHUD.push_back(option);
 #endif
 
-    if (((BzfWindow*) getMainWindow()->getWindow())->hasGammaControl())
-    {
-        option = new HUDuiList;
-        option->setFontFace(fontFace);
-        option->setLabel("Brightness:");
-        option->setCallback(callback, "g");
-        option->createSlider(15);
-        option->update();
-        listHUD.push_back(option);
-    }
 
-    option = new HUDuiList;
-    option->setFontFace(fontFace);
-
-#if (defined(HAVE_SDL) && !defined(HAVE_SDL2))  // only SDL 2 can make live changes
-    option->setLabel("(restart required) Energy Saver:");
-#else
-    option->setLabel("Energy Saver:");
-#endif
-    option->setCallback(callback, "s");
-    options = &option->getList();
-    options->push_back(std::string("Off"));
-    options->push_back(std::string("FPS Limit"));
-    if (getMainWindow()->getWindow()->hasVerticalSync())
-        options->push_back(std::string("Vertical Sync"));
-    option->update();
-    listHUD.push_back(option);
-
-    if (OpenGLGState::getMaxSamples() > 1)
-    {
-        option = new HUDuiList;
-        option->setFontFace(fontFace);
-        option->setLabel("Anti Aliasing:");
-        option->setCallback(callback, "m");
-        options = &option->getList();
-        options->push_back(std::string("Off"));
-        for (int i = 2; i <= OpenGLGState::getMaxSamples(); ++i)
-        {
-            char msaaText[11];
-            snprintf(msaaText, 11, "%i", i);
-            options->push_back(std::string(msaaText) + "x MSAA");
-        }
-        option->update();
-        listHUD.push_back(option);
-    }
 
     BzfDisplay* display = getDisplay();
     int numFormats = display->getNumResolutions();
@@ -291,7 +291,12 @@ void            DisplayMenu::resize(int _width, int _height)
 
     // use a big font for title, smaller font for the rest
     const float titleFontSize = (float)_height / 15.0f;
-    const float fontSize = (float)_height / 45.0f;
+#if defined(DEBUG_RENDERING)
+    const float fontSize = (float)_height / 55.0f;
+#else
+    const float fontSize = (float)_height / 40.0f;
+#endif
+
     FontManager &fm = FontManager::instance();
     int fontFace = MainMenu::getFontFace();
 
@@ -314,7 +319,11 @@ void            DisplayMenu::resize(int _width, int _height)
     {
         listHUD[i]->setFontSize(fontSize);
         listHUD[i]->setPosition(x, y);
-        y -= 1.0f * h;
+        // Add extra space after Shadows, AntiFlicker, Smoothing, Brightness, Energy Saver and before Change Video Format
+        if (i == 4 || i == 7 || i == 10 || i == 11 || i == 12 || i == count - 2)
+            y -= 1.75f * h;
+        else
+            y -= 1.0f * h;
     }
 
     i = 1;
@@ -323,9 +332,14 @@ void            DisplayMenu::resize(int _width, int _height)
     if (renderer)
     {
         TextureManager& tm = TextureManager::instance();
-        ((HUDuiList*)listHUD[i++])->setIndex(BZDB.isTrue("dither"));
-        ((HUDuiList*)listHUD[i++])->setIndex(BZDB.isTrue("blend"));
-        ((HUDuiList*)listHUD[i++])->setIndex(BZDB.isTrue("smooth"));
+
+        // Quality
+        ((HUDuiList*)listHUD[i++])->setIndex(renderer->useQuality());
+
+        // Texturing
+        ((HUDuiList*)listHUD[i++])->setIndex(tm.getMaxFilter());
+
+        // Lighting
         if (BZDBCache::lighting)
         {
             if (BZDB.isTrue("tesselation"))
@@ -335,20 +349,8 @@ void            DisplayMenu::resize(int _width, int _height)
         }
         else
             ((HUDuiList*)listHUD[i++])->setIndex(0);
-        ((HUDuiList*)listHUD[i++])->setIndex(tm.getMaxFilter());
-        ((HUDuiList*)listHUD[i++])->setIndex(BZDB.isTrue("remapTexCoords") ? 1 : 0);
-        if (OpenGLGState::hasAnisotropicFiltering)
-        {
-            static GLint maxAnisotropy = 1;
-            glGetIntegerv(GL_MAX_TEXTURE_MAX_ANISOTROPY_EXT, &maxAnisotropy);
-            if (maxAnisotropy > 1)
-            {
-                int aniso = BZDB.evalInt("aniso");
-                aniso = (aniso < 1) ? 1 : aniso;
-                ((HUDuiList*)listHUD[i++])->setIndex(BZDB.evalInt("aniso") - 1);
-            }
-        }
-        ((HUDuiList*)listHUD[i++])->setIndex(renderer->useQuality());
+
+        // Shadows
         int shadowVal = 0;
         if (BZDBCache::shadows)
         {
@@ -357,30 +359,60 @@ void            DisplayMenu::resize(int _width, int _height)
                 shadowVal++;
         }
         ((HUDuiList*)listHUD[i++])->setIndex(shadowVal);
+
+
+
+        // Multi-Samping
+        if (OpenGLGState::getMaxSamples() > 1)
+        {
+            // multisampling
+            int multisampleLevel = BZDB.evalInt("multisample");
+            int multisampleIndex = 0;
+            while (multisampleLevel > pow(2, multisampleIndex))
+                multisampleIndex++;
+            ((HUDuiList*)listHUD[i++])->setIndex(multisampleIndex);
+        }
+
+        // Anisotropic filtering
+        if (OpenGLGState::hasAnisotropicFiltering)
+        {
+            static GLint maxAnisotropy = 1;
+            glGetIntegerv(GL_MAX_TEXTURE_MAX_ANISOTROPY_EXT, &maxAnisotropy);
+            if (maxAnisotropy > 1)
+            {
+                int anisoLevel = BZDB.evalInt("aniso");
+                int anisoIndex = 0;
+                while (anisoLevel > pow(2, anisoIndex))
+                    anisoIndex++;
+                ((HUDuiList*)listHUD[i++])->setIndex(anisoIndex);
+            }
+        }
+
+        // Anti-Flicker
+        ((HUDuiList*)listHUD[i++])->setIndex(BZDB.isTrue("remapTexCoords") ? 1 : 0);
+
+
+
+        ((HUDuiList*)listHUD[i++])->setIndex(BZDB.isTrue("dither"));
+        ((HUDuiList*)listHUD[i++])->setIndex(BZDB.isTrue("blend"));
+        ((HUDuiList*)listHUD[i++])->setIndex(BZDB.isTrue("smooth"));
+
+
+        // brightness
+        BzfWindow* window = getMainWindow()->getWindow();
+        if (window->hasGammaControl())
+            ((HUDuiList*)listHUD[i++])->setIndex(gammaToIndex(window->getGamma()));
+
+        // energy saver
+        ((HUDuiList*)listHUD[i++])->setIndex(BZDB.evalInt("saveEnergy"));
+
 #if defined(DEBUG_RENDERING)
-        ((HUDuiList*)listHUD[i++])->setIndex(renderer->useHiddenLine() ? 1 : 0);
-        ((HUDuiList*)listHUD[i++])->setIndex(BZDB.isTrue("wireframe") ? 1 : 0);
-        ((HUDuiList*)listHUD[i++])->setIndex(renderer->useDepthComplexity() ? 1
-                                             : 0);
+        ((HUDuiList*)listHUD[i++])->setIndex(renderer->useHiddenLine() ? 1 : (renderer->useWireframe() ? 2 : 0));
+        ((HUDuiList*)listHUD[i++])->setIndex(renderer->useDepthComplexity() ? 1 : 0);
         ((HUDuiList*)listHUD[i++])->setIndex(BZDBCache::showCullingGrid ? 1 : 0);
-        ((HUDuiList*)listHUD[i++])->setIndex(BZDBCache::showCollisionGrid ? 1
-                                             : 0);
+        ((HUDuiList*)listHUD[i++])->setIndex(BZDBCache::showCollisionGrid ? 1 : 0);
 #endif
     }
-
-    // brightness
-    BzfWindow* window = getMainWindow()->getWindow();
-    if (window->hasGammaControl())
-        ((HUDuiList*)listHUD[i++])->setIndex(gammaToIndex(window->getGamma()));
-
-    // energy saver
-    ((HUDuiList*)listHUD[i++])->setIndex(BZDB.evalInt("saveEnergy"));
-
-    if (OpenGLGState::getMaxSamples() > 1)
-    {
-        // multisampling
-        ((HUDuiList*)listHUD[i++])->setIndex(BZDB.evalInt("multisample") - 1);
-    }
 }
 
 int DisplayMenu::gammaToIndex(float gamma)
@@ -442,8 +474,8 @@ void            DisplayMenu::callback(HUDuiControl* w, const void* data)
     }
     case 'A':
     {
-        int aniso = list->getIndex() + 1;
-        BZDB.setInt("aniso", aniso);
+        int aniso = list->getIndex();
+        BZDB.setInt("aniso", (aniso == 0)?0:(int)pow(2, aniso));
         TextureManager& tm = TextureManager::instance();
         tm.setMaxFilter(tm.getMaxFilter());
         sceneRenderer->notifyStyleChange();
@@ -451,7 +483,7 @@ void            DisplayMenu::callback(HUDuiControl* w, const void* data)
     }
     case '6':
         sceneRenderer->setQuality(list->getIndex());
-        if (list->getIndex() > 3)
+        if (list->getIndex() >= 3)
         {
             BZDB.set("zbuffer","1");
             setSceneDatabase();
@@ -469,11 +501,9 @@ void            DisplayMenu::callback(HUDuiControl* w, const void* data)
         sceneRenderer->notifyStyleChange();
         break;
     }
-    case 'a':
-        sceneRenderer->setHiddenLine(list->getIndex() != 0);
-        break;
     case 'b':
-        BZDB.setBool("wireframe", (list->getIndex() != 0));
+        sceneRenderer->setHiddenLine(list->getIndex() == 1);
+        sceneRenderer->setWireframe(list->getIndex() == 2);
         break;
     case 'c':
         sceneRenderer->setDepthComplexity(list->getIndex() != 0);
@@ -489,8 +519,11 @@ void            DisplayMenu::callback(HUDuiControl* w, const void* data)
         getMainWindow()->getWindow()->setVerticalSync(list->getIndex() == 2);
         break;
     case 'm':
-        BZDB.setInt("multisample", list->getIndex() + 1);
+    {
+        int multi = list->getIndex();
+        BZDB.setInt("multisample", (multi == 0)?0:(int)pow(2, multi));
         break;
+    }
     case 'g':
         BzfWindow* window = getMainWindow()->getWindow();
         if (window->hasGammaControl())
