@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2017 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -24,31 +24,32 @@
 
 /** this class provides options for setting the gui
  */
-class DisplayMenu : public HUDDialog {
+class DisplayMenu : public HUDDialog
+{
 public:
-  DisplayMenu();
-  ~DisplayMenu();
+    DisplayMenu();
+    ~DisplayMenu();
 
-  HUDuiDefaultKey* getDefaultKey()
-  {
-    return MenuDefaultKey::getInstance();
-  }
-  void execute();
-  void resize(int width, int height);
-  static void callback(HUDuiControl* w, const void* data);
+    HUDuiDefaultKey* getDefaultKey()
+    {
+        return MenuDefaultKey::getInstance();
+    }
+    void execute();
+    void resize(int width, int height);
+    static void callback(HUDuiControl* w, const void* data);
 private:
-  FormatMenu*	formatMenu;
-  HUDuiControl*	videoFormat;
-  static int	gammaToIndex(float);
-  static float	indexToGamma(int);
+    FormatMenu*   formatMenu;
+    HUDuiControl* videoFormat;
+    static int    gammaToIndex(float);
+    static float  indexToGamma(int);
 };
 
 #endif /* __DISPLAYMENU_H__ */
 
 // Local Variables: ***
 // mode: C++ ***
-// tab-width: 8 ***
-// c-basic-offset: 2 ***
-// indent-tabs-mode: t ***
+// tab-width: 4 ***
+// c-basic-offset: 4 ***
+// indent-tabs-mode: nil ***
 // End: ***
-// ex: shiftwidth=2 tabstop=8
+// ex: shiftwidth=4 tabstop=4
