@@ -356,16 +356,28 @@ void            HUDRenderer::setFPS(float _fps)
 
 void            HUDRenderer::setDrawTime(float drawTimeInseconds)
 {
+    const int maxCnt = 10000;
+    if (drawTimeInseconds < 0)
+    {
+        drawTime = drawTimeInseconds;
+        return;
+    }
     if (drawTime < 0.)
+        drawTimeCnt = maxCnt;
+    if (drawTimeCnt == maxCnt)
     {
         minDrawTime = drawTimeInseconds;
         maxDrawTime = drawTimeInseconds;
+        drawTimeTmp = 0;
+        drawTimeCnt = 0;
     }
-    drawTime = drawTimeInseconds;
-    if (drawTime < minDrawTime)
+    else if (drawTime < minDrawTime)
         minDrawTime = drawTime;
     else if (drawTime > maxDrawTime)
         maxDrawTime = drawTime;
+    drawTimeTmp += drawTimeInseconds;
+    drawTimeCnt++;
+    drawTime = drawTimeTmp / drawTimeCnt;
 }
 
 void            HUDRenderer::setFrameTriangleCount(int tpf)
@@ -773,20 +785,8 @@ void            HUDRenderer::render(SceneRenderer& renderer)
 
         if (showCompose || showTimes || showTankLabels)
         {
-            // get view metrics
-            const int width = window.getWidth();
-            const int height = window.getHeight();
-            const int viewHeight = window.getViewHeight();
-            const int ox = window.getOriginX();
-            const int oy = window.getOriginY();
             // use one-to-one pixel projection
-            glScissor(ox, oy + height - viewHeight, width, viewHeight);
-            glMatrixMode(GL_PROJECTION);
-            glLoadIdentity();
-            glOrtho(0.0, width, viewHeight - height, viewHeight, -1.0, 1.0);
-            glMatrixMode(GL_MODELVIEW);
-            glPushMatrix();
-            glLoadIdentity();
+            setOneToOnePrj();
 
             if (showCompose)
                 renderCompose(renderer);
@@ -1209,10 +1209,10 @@ void            HUDRenderer::renderTimes(void)
     }
     if (drawTime > 0.0f)
     {
-        const std::string buf = TextUtils::format("time: %d/%d/%dms",
-                                int(minDrawTime * 1000.0f),
-                                int(drawTime * 1000.0f),
-                                int(maxDrawTime * 1000.0f));
+        const std::string buf = TextUtils::format("time: %.2f/%.2f/%.2f ms",
+                                minDrawTime * 1000.0f,
+                                drawTime * 1000.0f,
+                                maxDrawTime * 1000.0f);
         hudColor3f(1.0f, 1.0f, 1.0f);
         fm.drawString((float)(centerx + maxMotionSize) - fm.getStrLength(headingFontFace, headingFontSize, buf),
                       (float)centery + (float)maxMotionSize +
@@ -1481,17 +1481,6 @@ void            HUDRenderer::renderBox(SceneRenderer&)
         glVertex2i(centerx - noMotionSize, centery + noMotionSize);
     }
     glEnd();
-    if (0)
-    {
-        glBegin(GL_POINTS);
-        {
-            glVertex2i(centerx - noMotionSize, centery - noMotionSize);
-            glVertex2i(centerx + noMotionSize, centery - noMotionSize);
-            glVertex2i(centerx + noMotionSize, centery + noMotionSize);
-            glVertex2i(centerx - noMotionSize, centery + noMotionSize);
-        }
-        glEnd();
-    }
     glBegin(GL_LINE_LOOP);
     {
         glVertex2i(centerx - maxMotionSize, centery - maxMotionSize);
@@ -1500,17 +1489,6 @@ void            HUDRenderer::renderBox(SceneRenderer&)
         glVertex2i(centerx - maxMotionSize, centery + maxMotionSize);
     }
     glEnd();
-    if (0)
-    {
-        glBegin(GL_POINTS);
-        {
-            glVertex2i(centerx - maxMotionSize, centery - maxMotionSize);
-            glVertex2i(centerx + maxMotionSize, centery - maxMotionSize);
-            glVertex2i(centerx + maxMotionSize, centery + maxMotionSize);
-            glVertex2i(centerx - maxMotionSize, centery + maxMotionSize);
-        }
-        glEnd();
-    }
 
     // draw heading strip
     if (true /* always draw heading strip */)
@@ -1760,7 +1738,7 @@ void HUDRenderer::drawMarkersInView( int centerx, int centery, const LocalPlayer
 }
 
 
-void            HUDRenderer::renderPlaying(SceneRenderer& renderer)
+void            HUDRenderer::setOneToOnePrj()
 {
     // get view metrics
     const int width = window.getWidth();
@@ -1768,28 +1746,52 @@ void            HUDRenderer::renderPlaying(SceneRenderer& renderer)
     const int viewHeight = window.getViewHeight();
     const int ox = window.getOriginX();
     const int oy = window.getOriginY();
+
+    // use one-to-one pixel projection
+    glScissor(ox, oy + height - viewHeight, width, viewHeight);
+    glMatrixMode(GL_PROJECTION);
+    window.setProjectionHUD();
+    glMatrixMode(GL_MODELVIEW);
+    glPushMatrix();
+    glLoadIdentity();
+}
+
+
+void            HUDRenderer::coverWhenBurrowed(const LocalPlayer &myTank)
+{
+    const float z = myTank.getPosition()[2];
+    if (z >= 0.0f)
+        return;
+
+    const int width = window.getWidth();
+    const int viewHeight = window.getViewHeight();
+
+    // cover the lower portion of the screen when burrowed
+    GLfloat y2 = z /
+                 (BZDB.eval(StateDatabase::BZDB_BURROWDEPTH) - 0.1f) *
+                 (float)viewHeight / 2.0f;
+    glColor4f(0.02f, 0.01f, 0.01f, 1.0);
+    glRectf(0.0f, 0.0f, (float)width, y2);
+}
+
+
+void            HUDRenderer::renderPlaying(SceneRenderer& renderer)
+{
+    // get view metrics
+    const int width = window.getWidth();
+    const int height = window.getHeight();
+    const int viewHeight = window.getViewHeight();
     const int centerx = width >> 1;
     const int centery = viewHeight >> 1;
 
     FontManager &fm = FontManager::instance();
 
-    // use one-to-one pixel projection
-    glScissor(ox, oy + height - viewHeight, width, viewHeight);
-    glMatrixMode(GL_PROJECTION);
-    glLoadIdentity();
-    glOrtho(0.0, width, viewHeight - height, viewHeight, -1.0, 1.0);
-    glMatrixMode(GL_MODELVIEW);
-    glPushMatrix();
-    glLoadIdentity();
+    setOneToOnePrj();
 
     // cover the lower portion of the screen when burrowed
     const LocalPlayer *myTank = LocalPlayer::getMyTank();
-    if (myTank && myTank->getPosition()[2] < 0.0f)
-    {
-        glColor4f(0.02f, 0.01f, 0.01f, 1.0);
-        glRectf(0, 0, (float)width, (myTank->getPosition()[2]/(BZDB.eval(StateDatabase::BZDB_BURROWDEPTH)-0.1f)) * ((
-                    float)viewHeight/2.0f));
-    }
+    if (myTank)
+        coverWhenBurrowed(*myTank);
 
     // draw shot reload status
     if (BZDB.isTrue("displayReloadTimer"))
@@ -1872,21 +1874,12 @@ void            HUDRenderer::renderNotPlaying(SceneRenderer& renderer)
 {
     // get view metrics
     const int width = window.getWidth();
-    const int height = window.getHeight();
     const int viewHeight = window.getViewHeight();
-    const int ox = window.getOriginX();
-    const int oy = window.getOriginY();
 
     FontManager &fm = FontManager::instance();
 
     // use one-to-one pixel projection
-    glScissor(ox, oy + height - viewHeight, width, viewHeight);
-    glMatrixMode(GL_PROJECTION);
-    glLoadIdentity();
-    glOrtho(0.0, width, viewHeight - height, viewHeight, -1.0, 1.0);
-    glMatrixMode(GL_MODELVIEW);
-    glPushMatrix();
-    glLoadIdentity();
+    setOneToOnePrj();
 
     // draw cracks
     if (showCracks)
@@ -1949,29 +1942,16 @@ void            HUDRenderer::renderRoaming(SceneRenderer& renderer)
     // get view metrics
     const int width = window.getWidth();
     const int height = window.getHeight();
-    const int viewHeight = window.getViewHeight();
-    const int ox = window.getOriginX();
-    const int oy = window.getOriginY();
 
     FontManager &fm = FontManager::instance();
 
     // use one-to-one pixel projection
-    glScissor(ox, oy + height - viewHeight, width, viewHeight);
-    glMatrixMode(GL_PROJECTION);
-    glLoadIdentity();
-    glOrtho(0.0, width, viewHeight - height, viewHeight, -1.0, 1.0);
-    glMatrixMode(GL_MODELVIEW);
-    glPushMatrix();
-    glLoadIdentity();
+    setOneToOnePrj();
 
     // black out the underground if we're driving with a tank with BU
     LocalPlayer *myTank = LocalPlayer::getMyTank();
-    if (myTank && myTank->getPosition()[2] < 0.0f)
-    {
-        glColor4f(0.02f, 0.01f, 0.01f, 1.0);
-        glRectf(0, 0, (float)width, (myTank->getPosition()[2]/(BZDB.eval(StateDatabase::BZDB_BURROWDEPTH)-0.1f)) * ((
-                    float)viewHeight/2.0f));
-    }
+    if (myTank)
+        coverWhenBurrowed(*myTank);
 
     // draw shot reload status
     if ((ROAM.getMode() == Roaming::roamViewFP) && BZDB.isTrue("displayReloadTimer"))
