@@ -164,6 +164,8 @@ private:
     void      setHeadingFontSize(int width, int height);
     void      setComposeFontSize(int width, int height);
     void      setLabelsFontSize(int width, int height);
+    void      setOneToOnePrj();
+    void      coverWhenBurrowed(const LocalPlayer &myTank);
 
     void      resize(bool firstTime);
     static void   resizeCallback(void*);
@@ -210,7 +212,9 @@ private:
     float     fps;
     float     minDrawTime;
     float     drawTime;
+    float     drawTimeTmp;
     float     maxDrawTime;
+    int       drawTimeCnt;
     float     headingMarkSpacing;
     float     headingLabelWidth[36];
     float     altitudeMarkSpacing;
