@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2017 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -12,29 +12,30 @@
 
 /*
  * HUDuiDefaultKey:
- *	User interface class for the heads-up display.
+ *  User interface class for the heads-up display.
  */
 
-#ifndef	__HUDUIDEFAULTKEY_H__
-#define	__HUDUIDEFAULTKEY_H__
+#ifndef __HUDUIDEFAULTKEY_H__
+#define __HUDUIDEFAULTKEY_H__
 
 #include "BzfEvent.h"
 
-class HUDuiDefaultKey {
-  public:
-			HUDuiDefaultKey();
-    virtual		~HUDuiDefaultKey();
+class HUDuiDefaultKey
+{
+public:
+    HUDuiDefaultKey();
+    virtual     ~HUDuiDefaultKey();
 
-    virtual bool	keyPress(const BzfKeyEvent&);
-    virtual bool	keyRelease(const BzfKeyEvent&);
+    virtual bool    keyPress(const BzfKeyEvent&);
+    virtual bool    keyRelease(const BzfKeyEvent&);
 };
 
 #endif // __HUDUIDEFAULTKEY_H__
 
 // Local Variables: ***
 // mode: C++ ***
-// tab-width: 8 ***
-// c-basic-offset: 2 ***
-// indent-tabs-mode: t ***
+// tab-width: 4 ***
+// c-basic-offset: 4 ***
+// indent-tabs-mode: nil ***
 // End: ***
-// ex: shiftwidth=2 tabstop=8
+// ex: shiftwidth=4 tabstop=4
