@@ -43,20 +43,6 @@ static bool mapFog;
 static bool setupMapFog();
 
 
-#ifdef GL_ABGR_EXT
-static int      strrncmp(const char* s1, const char* s2, int num)
-{
-    int len1 = strlen(s1) - 1;
-    int len2 = strlen(s2) - 1;
-    for (; len1 >= 0 && len2 >= 0 && num > 0; len1--, len2--, num--)
-    {
-        const int d = (int)s1[len1] - (int)s2[len2];
-        if (d != 0) return d;
-    }
-    return 0;
-}
-#endif
-
 //
 // FlareLight
 //
@@ -85,10 +71,6 @@ const float   SceneRenderer::dimDensity = 0.75f;
 const GLfloat SceneRenderer::dimnessColor[4] = { 0.0f, 0.0f, 0.0f, 1.0f };
 const GLfloat SceneRenderer::blindnessColor[4] = { 1.0f, 1.0f, 0.0f, 1.0f };
 
-/* initialize the singleton */
-template <>
-SceneRenderer* Singleton<SceneRenderer>::_instance = (SceneRenderer*)0;
-
 SceneRenderer::SceneRenderer() :
     window(NULL),
     blank(false),
@@ -96,14 +78,13 @@ SceneRenderer::SceneRenderer() :
     sunBrightness(1.0f),
     scene(NULL),
     background(NULL),
-    abgr(false),
     useQualityValue(2),
     useDepthComplexityOn(false),
     useWireframeOn(false),
     useHiddenLineOn(false),
     panelOpacity(0.3f),
     radarOpacity(0.3f),
-    radarSize(4),
+    radarSize(8),
     panelHeight(4),
     maxMotionFactor(5),
     viewType(Normal),
@@ -128,6 +109,10 @@ SceneRenderer::SceneRenderer() :
     // init the track mark manager
     TrackMarks::init();
 
+    // add callbacks for radar size and panel height
+    BZDB.addCallback("radarsize", bzdbCallback, NULL);
+    BZDB.addCallback("panelheight", bzdbCallback, NULL);
+
     return;
 }
 
@@ -147,36 +132,6 @@ void SceneRenderer::setWindow(MainWindow* _window)
     glGetIntegerv(GL_STENCIL_BITS, &bits);
     useStencilOn = (bits > 0);
 
-    // see if abgr extention is available and system is known to be
-    // faster with abgr.
-    const char* vendor = (const char*)glGetString(GL_VENDOR);
-    const char* renderer = (const char*)glGetString(GL_RENDERER);
-    const char* version = (const char*)glGetString(GL_VERSION);
-    const char* extensions = (const char*)glGetString(GL_EXTENSIONS);
-    (void)vendor;
-    (void)renderer;
-    (void)version;
-    (void)extensions; // silence g++
-#ifdef GL_ABGR_EXT
-    if ((extensions != NULL && strstr(extensions, "GL_EXT_abgr") != NULL) &&
-            (vendor != NULL && strcmp(vendor, "SGI") == 0))
-    {
-        // old hardware is faster with ABGR.  new hardware isn't.
-        if ((renderer != NULL) &&
-                (strncmp(renderer, "GR1", 3) == 0 ||
-                 strncmp(renderer, "VGX", 3) == 0 ||
-                 strncmp(renderer, "LIGHT", 5) == 0 ||
-                 strrncmp(renderer, "-XS", 3) == 0 ||
-                 strrncmp(renderer, "-XSM", 4) == 0 ||
-                 strrncmp(renderer, "-XS24", 5) == 0 ||
-                 strrncmp(renderer, "-XS24-Z", 7) == 0 ||
-                 strrncmp(renderer, "-XZ", 3) == 0 ||
-                 strrncmp(renderer, "-Elan", 5) == 0 ||
-                 strrncmp(renderer, "-Extreme", 8) == 0))
-            abgr = true;
-    }
-#endif
-
     // can only do hidden line if polygon offset is available
     canUseHiddenLine = true;
 
@@ -207,12 +162,6 @@ SceneRenderer::~SceneRenderer()
 }
 
 
-bool SceneRenderer::useABGR() const
-{
-    return abgr;
-}
-
-
 bool SceneRenderer::useStencil() const
 {
     return useStencilOn;
@@ -369,6 +318,15 @@ void SceneRenderer::setRebuildTanks()
 }
 
 
+void SceneRenderer::bzdbCallback(const std::string& name, void *)
+{
+    if(name == "radarsize")
+        RENDERER.setRadarSize(BZDB.evalInt("radarsize"));
+    else if(name == "panelheight")
+        RENDERER.setPanelHeight(BZDB.evalInt("panelheight"));
+}
+
+
 void SceneRenderer::setupBackgroundMaterials()
 {
     if (background)
@@ -838,6 +796,7 @@ void SceneRenderer::render(bool _lastFrame, bool _sameFrame,
             mirrorColor[3] = 0.2f;
         }
 
+        float extent = 1.0f;
         // darken the reflection
         if (!mapFog)
         {
@@ -845,24 +804,6 @@ void SceneRenderer::render(bool _lastFrame, bool _sameFrame,
             glLoadIdentity();
             glMatrixMode(GL_MODELVIEW);
             glLoadIdentity();
-            // if low quality then use stipple -- it's probably much faster
-            if (BZDBCache::blend && (useQualityValue >= 1))
-            {
-                glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
-                glEnable(GL_BLEND);
-                glColor4fv(mirrorColor);
-                glRectf(-1.0f, -1.0f, +1.0f, +1.0f);
-                glDisable(GL_BLEND);
-            }
-            else
-            {
-                float stipple = mirrorColor[3];
-                glColor3fv(mirrorColor);
-                OpenGLGState::setStipple(stipple);
-                glEnable(GL_POLYGON_STIPPLE);
-                glRectf(-1.0f, -1.0f, +1.0f, +1.0f);
-                glDisable(GL_POLYGON_STIPPLE);
-            }
         }
         else
         {
@@ -870,24 +811,29 @@ void SceneRenderer::render(bool _lastFrame, bool _sameFrame,
             // if low quality then use stipple -- it's probably much faster
             frustum.executeView();
             frustum.executeProjection();
-            const float extent = BZDBCache::worldSize * 10.0f;
-            if (BZDBCache::blend && (useQualityValue >= 1))
-            {
-                glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
-                glEnable(GL_BLEND);
-                glColor4fv(mirrorColor);
-                glRectf(-extent, -extent, +extent, +extent);
-                glDisable(GL_BLEND);
-            }
-            else
-            {
-                float stipple = mirrorColor[3];
-                glColor3fv(mirrorColor);
-                OpenGLGState::setStipple(stipple);
-                glEnable(GL_POLYGON_STIPPLE);
-                glRectf(-extent, -extent, +extent, +extent);
-                glDisable(GL_POLYGON_STIPPLE);
-            }
+            extent = BZDBCache::worldSize * 10.0f;
+        }
+        // if low quality then use stipple -- it's probably much faster
+        if (BZDBCache::blend && (useQualityValue >= 1))
+        {
+            glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
+            glEnable(GL_BLEND);
+            glColor4fv(mirrorColor);
+        }
+        else
+        {
+            float stipple = mirrorColor[3];
+            glColor3fv(mirrorColor);
+            OpenGLGState::setStipple(stipple);
+            glEnable(GL_POLYGON_STIPPLE);
+        }
+        glRectf(-extent, -extent, +extent, +extent);
+        if (BZDBCache::blend && (useQualityValue >= 1))
+            glDisable(GL_BLEND);
+        else
+            glDisable(GL_POLYGON_STIPPLE);
+        if (mapFog)
+        {
             glMatrixMode(GL_PROJECTION);
             glLoadIdentity();
             glMatrixMode(GL_MODELVIEW);
@@ -1001,6 +947,10 @@ void SceneRenderer::renderScene(bool UNUSED(_lastFrame), bool UNUSED(_sameFrame)
 
     // draw start of background (no depth testing)
     OpenGLGState::resetState();
+
+    const GLdouble plane[4] = {0.0, 0.0, +1.0, 0.0};
+    glClipPlane(GL_CLIP_PLANE0, plane);
+
     if (background)
     {
         background->setBlank(blank);
@@ -1215,18 +1165,17 @@ void SceneRenderer::renderDimming()
 
         // if low quality then use stipple -- it's probably much faster
         if (BZDBCache::blend && (useQualityValue >= 1))
-        {
             glEnable(GL_BLEND);
-            glRectf(-1.0f, -1.0f, 1.0f, 1.0f);
-            glDisable(GL_BLEND);
-        }
         else
         {
             OpenGLGState::setStipple(density);
             glEnable(GL_POLYGON_STIPPLE);
-            glRectf(-1.0f, -1.0f, 1.0f, 1.0f);
-            glDisable(GL_POLYGON_STIPPLE);
         }
+        glRectf(-1.0f, -1.0f, +1.0f, +1.0f);
+        if (BZDBCache::blend && (useQualityValue >= 1))
+            glDisable(GL_BLEND);
+        else
+            glDisable(GL_POLYGON_STIPPLE);
     }
     return;
 }
