@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2017 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -10,8 +10,8 @@
  * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
-#ifndef	__SHOTSTATSDEFAULTKEY_H__
-#define	__SHOTSTATSDEFAULTKEY_H__
+#ifndef __SHOTSTATSDEFAULTKEY_H__
+#define __SHOTSTATSDEFAULTKEY_H__
 
 /* common interface headers */
 #include "BzfEvent.h"
@@ -19,17 +19,18 @@
 /* local interface headers */
 #include "HUDuiDefaultKey.h"
 
-class ShotStatsDefaultKey : public HUDuiDefaultKey {
+class ShotStatsDefaultKey : public HUDuiDefaultKey
+{
 public:
-  ShotStatsDefaultKey();
-  ~ShotStatsDefaultKey();
+    ShotStatsDefaultKey();
+    ~ShotStatsDefaultKey();
 
-  bool keyPress(const BzfKeyEvent&);
-  bool keyRelease(const BzfKeyEvent&);
-  static ShotStatsDefaultKey* getInstance();
+    bool keyPress(const BzfKeyEvent&);
+    bool keyRelease(const BzfKeyEvent&);
+    static ShotStatsDefaultKey* getInstance();
 
 private:
-  static ShotStatsDefaultKey instance;
+    static ShotStatsDefaultKey instance;
 };
 
 
@@ -37,8 +38,8 @@ private:
 
 // Local Variables: ***
 // mode: C++ ***
-// tab-width: 8 ***
-// c-basic-offset: 2 ***
-// indent-tabs-mode: t ***
+// tab-width: 4 ***
+// c-basic-offset: 4 ***
+// indent-tabs-mode: nil ***
 // End: ***
-// ex: shiftwidth=2 tabstop=8
+// ex: shiftwidth=4 tabstop=4
