@@ -37,12 +37,12 @@ DefaultDBItem defaultDBItems[] =
     { "radarStyle",       "3",            true,   StateDatabase::ReadWrite,   NULL },
     { "radarTankPixels",      "2.0",          true,   StateDatabase::ReadWrite,   NULL },
     { "coloredradarshots",    "1",            true,   StateDatabase::ReadWrite,   NULL },
-    { "linedradarshots",      "0",            true,   StateDatabase::ReadWrite,   NULL },
-    { "sizedradarshots",      "0",            true,   StateDatabase::ReadWrite,   NULL },
+    { "linedradarshots",      "5",            true,   StateDatabase::ReadWrite,   NULL },
+    { "sizedradarshots",      "4",            true,   StateDatabase::ReadWrite,   NULL },
     { "panelopacity",     "0.3",          true,   StateDatabase::ReadWrite,   NULL },
     { "radaropacity",     "0.3",          true,   StateDatabase::ReadWrite,   NULL },
     { "panelheight",      "4",            true,   StateDatabase::ReadWrite,   NULL },
-    { "radarsize",        "4",            true,   StateDatabase::ReadWrite,   NULL },
+    { "radarsize",        "8",            true,   StateDatabase::ReadWrite,   NULL },
     { "mouseboxsize",     "5",            true,   StateDatabase::ReadWrite,   NULL },
     { "mouseClamp",       "0",            true,   StateDatabase::ReadWrite,   NULL },
     { "cpanelfontsize",       "0",            true,   StateDatabase::ReadWrite,   NULL },
@@ -85,20 +85,20 @@ DefaultDBItem defaultDBItems[] =
     { "userMirror",       "1",            true,   StateDatabase::ReadWrite,   NULL },
     { "showTreads",       "0",            true,   StateDatabase::ReadWrite,   NULL },
     { "animatedTreads",       "1",            true,   StateDatabase::ReadWrite,   NULL },
-    { "shotLength",       "1",            true,   StateDatabase::ReadWrite,   NULL },
+    { "shotLength",       "6",            true,   StateDatabase::ReadWrite,   NULL },
     { "treadStyle",       "1",            true,   StateDatabase::ReadWrite,   NULL },
     { "userTrackFade",        "1.0",          true,   StateDatabase::ReadWrite,   NULL },
     { "trackMarkCulling",     "3",            true,   StateDatabase::ReadWrite,   NULL },
     { "scrollPages",      "20",           true,   StateDatabase::ReadWrite,   NULL },
     { "remoteSounds",     "1",            true,   StateDatabase::ReadWrite,   NULL },
-    { "leadingShotLine",      "0",            true,   StateDatabase::ReadWrite,   NULL },
+    { "leadingShotLine",      "1",            true,   StateDatabase::ReadWrite,   NULL },
     { "saveIdentity",     "2",            true,   StateDatabase::ReadWrite,   NULL },
     { "showCollisionGrid",    "0",            true,   StateDatabase::ReadWrite,   NULL },
     { "showCullingGrid",      "0",            true,   StateDatabase::ReadWrite,   NULL },
     { "showCoordinates",      "0",            true,   StateDatabase::ReadWrite,   NULL },
     { "showVelocities",       "0",            true,   StateDatabase::ReadWrite,   NULL },
     { "jumpTyping",       "1",            true,   StateDatabase::ReadWrite,   NULL },
-    { "maxCacheMB",       "32",           true,   StateDatabase::ReadWrite,   NULL },
+    { "maxCacheMB",       "512",           true,   StateDatabase::ReadWrite,   NULL },
     { "doDownloads",      "1",            true,   StateDatabase::ReadWrite,   NULL },
     { "updateDownloads",      "0",            true,   StateDatabase::ReadWrite,   NULL },
     { "roamSmoothTime",       "0.5",          true,   StateDatabase::ReadWrite,   NULL },
@@ -114,6 +114,14 @@ DefaultDBItem defaultDBItems[] =
     { "shotBrightness",       "0.2",          true,   StateDatabase::ReadWrite,   setColor },
     { "multisample",      "1",            true,   StateDatabase::ReadWrite,   NULL },
 
+    { "blend",      "1",            true,   StateDatabase::ReadWrite,   NULL },
+    { "smooth",      "1",            true,   StateDatabase::ReadWrite,   NULL },
+    { "lighting",      "1",            true,   StateDatabase::ReadWrite,   NULL },
+    { "tesselation",      "1",            true,   StateDatabase::ReadWrite,   NULL },
+    { "dither",      "0",            true,   StateDatabase::ReadWrite,   NULL },
+    { "shadows",      "1",            true,   StateDatabase::ReadWrite,   NULL },
+    { "stencilShadows",      "1",            true,   StateDatabase::ReadWrite,   NULL },
+
     // roam smooth follow settings
     { "followDist",       "32.0",         true,   StateDatabase::ReadWrite,   NULL },
     { "followHeight",     "8.0",          true,   StateDatabase::ReadWrite,   NULL },
