@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2017 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -25,13 +25,14 @@
 #include "WorldInfo.h"
 
 
-class CustomBase : public WorldFileObstacle {
-  public:
+class CustomBase : public WorldFileObstacle
+{
+public:
     CustomBase();
     virtual bool read(const char *cmd, std::istream&);
     virtual void writeToGroupDef(GroupDefinition*) const;
 
-  protected:
+protected:
     int color;
     bool triggerWorldWep;
     std::string worldWepType;
@@ -41,8 +42,8 @@ class CustomBase : public WorldFileObstacle {
 
 // Local variables: ***
 // mode: C++ ***
-// tab-width: 8 ***
-// c-basic-offset: 2 ***
-// indent-tabs-mode: t ***
+// tab-width: 4***
+// c-basic-offset: 4 ***
+// indent-tabs-mode: nil ***
 // End: ***
-// ex: shiftwidth=2 tabstop=8
+// ex: shiftwidth=4 tabstop=4
