@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2017 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -19,15 +19,19 @@
 /* common headers */
 #include "DynamicColor.h"
 
-class CustomDynamicColor : public WorldFileObject {
-  public:
+class CustomDynamicColor : public WorldFileObject
+{
+public:
     CustomDynamicColor();
     ~CustomDynamicColor();
     virtual bool read(const char *cmd, std::istream& input);
     virtual void writeToManager() const;
-    bool usesManager() { return true; }
+    bool usesManager()
+    {
+        return true;
+    }
 
-  private:
+private:
     mutable DynamicColor* color;
 };
 
@@ -35,8 +39,8 @@ class CustomDynamicColor : public WorldFileObject {
 
 // Local variables: ***
 // mode: C++ ***
-// tab-width: 8 ***
-// c-basic-offset: 2 ***
-// indent-tabs-mode: t ***
+// tab-width: 4***
+// c-basic-offset: 4 ***
+// indent-tabs-mode: nil ***
 // End: ***
-// ex: shiftwidth=2 tabstop=8
+// ex: shiftwidth=4 tabstop=4
