@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2017 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -27,57 +27,56 @@
 
 CustomMaterial::CustomMaterial()
 {
-  return;
+    return;
 }
 
 
 CustomMaterial::~CustomMaterial()
 {
-  return;
+    return;
 }
 
 
 bool CustomMaterial::read(const char *cmd, std::istream& input)
 {
-  bool materror;
+    bool materror;
 
-  if (parseMaterials(cmd, input, &material, 1, materror)) {
-    if (materror) {
-      return false;
+    if (parseMaterials(cmd, input, &material, 1, materror))
+    {
+        if (materror)
+            return false;
     }
-  }
-  else {
-    return WorldFileObject::read(cmd, input);
-  }
+    else
+        return WorldFileObject::read(cmd, input);
 
-  return true;
+    return true;
 }
 
 
 void CustomMaterial::writeToManager() const
 {
-  material.setName(name);
+    material.setName(name);
 
-  if ((name.size() > 0) && (MATERIALMGR.findMaterial(name) != NULL)) {
-    std::cout << "warning: duplicate material name"
-	      << " (" << name << ")" << std::endl;
-    std::cout << "	 the first material will be used" << std::endl;
-  }
+    if ((name.size() > 0) && (MATERIALMGR.findMaterial(name) != NULL))
+    {
+        std::cout << "warning: duplicate material name"
+                  << " (" << name << ")" << std::endl;
+        std::cout << "	 the first material will be used" << std::endl;
+    }
 
-  const BzMaterial* matref = MATERIALMGR.addMaterial(&material);
+    const BzMaterial* matref = MATERIALMGR.addMaterial(&material);
 
-  int index = MATERIALMGR.getIndex(matref);
-  if (index < 0) {
-    std::cout << "CustomMaterial::write: material didn't register" << std::endl;
-  }
-  return;
+    int index = MATERIALMGR.getIndex(matref);
+    if (index < 0)
+        std::cout << "CustomMaterial::write: material didn't register" << std::endl;
+    return;
 }
 
 
 // Local variables: ***
 // mode: C++ ***
-// tab-width: 8 ***
-// c-basic-offset: 2 ***
-// indent-tabs-mode: t ***
+// tab-width: 4***
+// c-basic-offset: 4 ***
+// indent-tabs-mode: nil ***
 // End: ***
-// ex: shiftwidth=2 tabstop=8
+// ex: shiftwidth=4 tabstop=4
