@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2017 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -23,18 +23,20 @@
 #include "BzMaterial.h"
 
 
-class CustomSphere : public WorldFileObstacle {
-  public:
+class CustomSphere : public WorldFileObstacle
+{
+public:
     CustomSphere();
     ~CustomSphere();
     virtual bool read(const char *cmd, std::istream& input);
     virtual void writeToGroupDef(GroupDefinition*) const;
 
-  private:
-    enum {
-      Edge,
-      Bottom,
-      MaterialCount
+private:
+    enum
+    {
+        Edge,
+        Bottom,
+        MaterialCount
     };
     static const char* sideNames[MaterialCount];
 
@@ -52,8 +54,8 @@ class CustomSphere : public WorldFileObstacle {
 
 // Local variables: ***
 // mode: C++ ***
-// tab-width: 8 ***
-// c-basic-offset: 2 ***
-// indent-tabs-mode: t ***
+// tab-width: 4***
+// c-basic-offset: 4 ***
+// indent-tabs-mode: nil ***
 // End: ***
-// ex: shiftwidth=2 tabstop=8
+// ex: shiftwidth=4 tabstop=4
