@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2017 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -29,16 +29,20 @@
 #include "WorldEventManager.h"
 
 
-class CustomWeapon : public WorldFileLocation {
-  public:
+class CustomWeapon : public WorldFileLocation
+{
+public:
     CustomWeapon();
     virtual bool read(const char *cmd, std::istream&);
     virtual void writeToWorld(WorldInfo*) const;
-    virtual bool usesGroupDef() { return false; }
+    virtual bool usesGroupDef()
+    {
+        return false;
+    }
 
     static const float minWeaponDelay;
 
-  protected:
+protected:
 
     FlagType *type;
 
@@ -58,8 +62,8 @@ class CustomWeapon : public WorldFileLocation {
 
 // Local variables: ***
 // mode: C++ ***
-// tab-width: 8 ***
-// c-basic-offset: 2 ***
-// indent-tabs-mode: t ***
+// tab-width: 4***
+// c-basic-offset: 4 ***
+// indent-tabs-mode: nil ***
 // End: ***
-// ex: shiftwidth=2 tabstop=8
+// ex: shiftwidth=4 tabstop=4
