@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2017 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -17,11 +17,12 @@
 class WorldInfo;
 
 
-namespace DropGeometry {
+namespace DropGeometry
+{
 
-  bool dropFlag (float pos[3], float minZ, float maxZ);
-  bool dropPlayer (float pos[3], float minZ, float maxZ);
-  bool dropTeamFlag (float pos[3], float minZ, float maxZ, int team);
+bool dropFlag (float pos[3], float minZ, float maxZ);
+bool dropPlayer (float pos[3], float minZ, float maxZ);
+bool dropTeamFlag (float pos[3], float minZ, float maxZ, int team);
 }
 
 
@@ -29,8 +30,8 @@ namespace DropGeometry {
 
 // Local variables: ***
 // mode: C++ ***
-// tab-width: 8 ***
-// c-basic-offset: 2 ***
-// indent-tabs-mode: t ***
+// tab-width: 4***
+// c-basic-offset: 4 ***
+// indent-tabs-mode: nil ***
 // End: ***
-// ex: shiftwidth=2 tabstop=8
+// ex: shiftwidth=4 tabstop=4
