@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2017 Tim Riker
+ * Copyright (c) 1993-2018 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -27,12 +27,13 @@
 #include "TimeKeeper.h"
 #include "cURLManager.h"
 
-class ListServerLink : cURLManager {
+class ListServerLink : cURLManager
+{
 public:
     // c'tor will fill list and local server information variables and
     // do an initial ADD
     ListServerLink(std::string listServerURL, std::string publicizedAddress,
-		   std::string publicizedTitle, std::string advertiseGroups);
+                   std::string publicizedTitle, std::string advertiseGroups);
     // c'tor with no arguments called when we don't want to use a list server.
     ListServerLink();
     // d'tor will REMOVE server and close connection
@@ -63,18 +64,18 @@ private:
 
     // messages to send, used by sendQueuedMessages
     void addMe(PingPacket pingInfo, std::string publicizedAddress,
-	       std::string publicizedTitle, std::string advertiseGroups);
+               std::string publicizedTitle, std::string advertiseGroups);
     void removeMe(std::string publicizedAddress);
     void sendQueuedMessages();
 
-  bool queuedRequest;
+    bool queuedRequest;
 };
 #endif //__LISTSERVERCONNECTION_H__
 
 // Local Variables: ***
 // mode: C++ ***
-// tab-width: 8 ***
-// c-basic-offset: 2 ***
-// indent-tabs-mode: t ***
+// tab-width: 4 ***
+// c-basic-offset: 4 ***
+// indent-tabs-mode: nil ***
 // End: ***
-// ex: shiftwidth=2 tabstop=8
+// ex: shiftwidth=4 tabstop=4
