@@ -188,6 +188,12 @@ bool load1Plugin ( std::string plugin, std::string config )
 
     std::string realPluginName = findPlugin(plugin);
 
+    if (realPluginName.empty())
+    {
+        logDebugMessage(1, "Plugin: %s is an invalid path or could not be found in known directories\n", plugin.c_str());
+        return false;
+    }
+
     HINSTANCE hLib = LoadLibrary(realPluginName.c_str());
     if (hLib)
     {
@@ -294,6 +300,12 @@ bool load1Plugin ( std::string plugin, std::string config )
 
     std::string realPluginName = findPlugin(plugin);
 
+    if (realPluginName.empty())
+    {
+        logDebugMessage(1, "Plugin: %s is an invalid path or could not be found in known directories\n", plugin.c_str());
+        return false;
+    }
+
     void *hLib = dlopen(realPluginName.c_str(), RTLD_LAZY | RTLD_GLOBAL);
     if (hLib)
     {
