@@ -23,20 +23,6 @@
 #include "TextUtils.h"
 
 
-// initialize the singleton
-template <>
-CommandManager* Singleton<CommandManager>::_instance = (CommandManager*)0;
-
-CommandManager::CommandManager()
-{
-    // do nothing
-}
-
-CommandManager::~CommandManager()
-{
-    // do nothing
-}
-
 void                CommandManager::add(const std::string& name,
                                         CommandFunction func,
                                         const std::string& help)
