@@ -10,9 +10,6 @@
  * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
-// bzflag common header
-#include "common.h"
-
 // interface header
 #include "BillboardSceneNode.h"
 
@@ -350,9 +347,6 @@ setFrameSize(float _du, float _dv)
 
 void            BillboardSceneNode::BillboardRenderNode::render()
 {
-    static const GLdouble groundPlane[] = { 0.0, 0.0, 1.0, 0.0 };
-
-    glClipPlane(GL_CLIP_PLANE0, groundPlane);
     glEnable(GL_CLIP_PLANE0);
 
     // want to move the billboard directly towards the eye a little bit.
