@@ -10,16 +10,13 @@
  * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
-// bzflag common header
-#include "common.h"
-
 // interface header
 #include "MeshFragSceneNode.h"
 
 // system headers
 #include <assert.h>
-#include <math.h>
-#include <string.h>
+#include <cmath>
+#include <cstring>
 
 // common implementation headers
 #include "Intersect.h"
@@ -41,27 +38,24 @@
 // NOTE: this should be based on visual pixel area
 static int minLightDisabling = 100;
 
-MeshFragSceneNode::Geometry::Geometry(MeshFragSceneNode* node)
+MeshFragSceneNode::Geometry::Geometry(MeshFragSceneNode &node)
+    : style(0)
+    , sceneNode(node)
 {
-    style = 0;
-    sceneNode = node;
     list = INVALID_GL_LIST_ID;
     OpenGLGState::registerContextInitializer (freeContext, initContext, this);
-    return;
 }
 
 
 MeshFragSceneNode::Geometry::~Geometry()
 {
     OpenGLGState::unregisterContextInitializer (freeContext, initContext, this);
-    return;
 }
 
 
 void MeshFragSceneNode::Geometry::init()
 {
     initDisplayList();
-    return;
 }
 
 
@@ -109,8 +103,8 @@ inline void MeshFragSceneNode::Geometry::drawV() const
     glDisableClientState(GL_NORMAL_ARRAY);
     glDisableClientState(GL_TEXTURE_COORD_ARRAY);
 
-    glVertexPointer(3, GL_FLOAT, 0, sceneNode->vertices);
-    glDrawArrays(GL_TRIANGLES, 0, sceneNode->arrayCount * 3);
+    glVertexPointer(3, GL_FLOAT, 0, sceneNode.vertices);
+    glDrawArrays(GL_TRIANGLES, 0, sceneNode.arrayCount * 3);
 
     glEnableClientState(GL_TEXTURE_COORD_ARRAY);
     glEnableClientState(GL_NORMAL_ARRAY);
@@ -123,9 +117,9 @@ inline void MeshFragSceneNode::Geometry::drawVT() const
 {
     glDisableClientState(GL_NORMAL_ARRAY);
 
-    glVertexPointer(3, GL_FLOAT, 0, sceneNode->vertices);
-    glTexCoordPointer(2, GL_FLOAT, 0, sceneNode->texcoords);
-    glDrawArrays(GL_TRIANGLES, 0, sceneNode->arrayCount * 3);
+    glVertexPointer(3, GL_FLOAT, 0, sceneNode.vertices);
+    glTexCoordPointer(2, GL_FLOAT, 0, sceneNode.texcoords);
+    glDrawArrays(GL_TRIANGLES, 0, sceneNode.arrayCount * 3);
 
     glEnableClientState(GL_NORMAL_ARRAY);
 
@@ -137,9 +131,9 @@ inline void MeshFragSceneNode::Geometry::drawVN() const
 {
     glDisableClientState(GL_TEXTURE_COORD_ARRAY);
 
-    glVertexPointer(3, GL_FLOAT, 0, sceneNode->vertices);
-    glNormalPointer(GL_FLOAT, 0, sceneNode->normals);
-    glDrawArrays(GL_TRIANGLES, 0, sceneNode->arrayCount * 3);
+    glVertexPointer(3, GL_FLOAT, 0, sceneNode.vertices);
+    glNormalPointer(GL_FLOAT, 0, sceneNode.normals);
+    glDrawArrays(GL_TRIANGLES, 0, sceneNode.arrayCount * 3);
 
     glEnableClientState(GL_TEXTURE_COORD_ARRAY);
 
@@ -149,10 +143,10 @@ inline void MeshFragSceneNode::Geometry::drawVN() const
 
 inline void MeshFragSceneNode::Geometry::drawVTN() const
 {
-    glVertexPointer(3, GL_FLOAT, 0, sceneNode->vertices);
-    glNormalPointer(GL_FLOAT, 0, sceneNode->normals);
-    glTexCoordPointer(2, GL_FLOAT, 0, sceneNode->texcoords);
-    glDrawArrays(GL_TRIANGLES, 0, sceneNode->arrayCount * 3);
+    glVertexPointer(3, GL_FLOAT, 0, sceneNode.vertices);
+    glNormalPointer(GL_FLOAT, 0, sceneNode.normals);
+    glTexCoordPointer(2, GL_FLOAT, 0, sceneNode.texcoords);
+    glDrawArrays(GL_TRIANGLES, 0, sceneNode.arrayCount * 3);
 
     return;
 }
@@ -160,14 +154,14 @@ inline void MeshFragSceneNode::Geometry::drawVTN() const
 
 void MeshFragSceneNode::Geometry::render()
 {
-    const int triangles = sceneNode->arrayCount;
+    const int triangles = sceneNode.arrayCount;
     const bool switchLights = (triangles >= minLightDisabling)
                               && BZDBCache::lighting;
     if (switchLights)
-        RENDERER.disableLights(sceneNode->extents.mins, sceneNode->extents.maxs);
+        RENDERER.disableLights(sceneNode.extents.mins, sceneNode.extents.maxs);
 
     // set the color
-    sceneNode->setColor();
+    sceneNode.setColor();
 
     if (list != INVALID_GL_LIST_ID)
         glCallList(list);
@@ -200,12 +194,12 @@ void MeshFragSceneNode::Geometry::render()
 
 void MeshFragSceneNode::Geometry::renderRadar()
 {
-    const int triangles = sceneNode->arrayCount;
+    const int triangles = sceneNode.arrayCount;
     if (list != INVALID_GL_LIST_ID)
         glCallList(list);
     else
     {
-        glVertexPointer(3, GL_FLOAT, 0, sceneNode->vertices);
+        glVertexPointer(3, GL_FLOAT, 0, sceneNode.vertices);
         glDrawArrays(GL_TRIANGLES, 0, triangles * 3);
     }
     addTriangleCount(triangles);
@@ -215,36 +209,40 @@ void MeshFragSceneNode::Geometry::renderRadar()
 
 void MeshFragSceneNode::Geometry::renderShadow()
 {
-    const int triangles = sceneNode->arrayCount;
+    const int triangles = sceneNode.arrayCount;
     if (list != INVALID_GL_LIST_ID)
         glCallList(list);
     else
     {
-        glVertexPointer(3, GL_FLOAT, 0, sceneNode->vertices);
+        glVertexPointer(3, GL_FLOAT, 0, sceneNode.vertices);
         glDrawArrays(GL_TRIANGLES, 0, triangles * 3);
     }
     addTriangleCount(triangles);
     return;
 }
 
+void MeshFragSceneNode::Geometry::setStyle(int style_)
+{
+    style = style_;
+}
 
 //
 // MeshFragSceneNode
 //
 
-MeshFragSceneNode::MeshFragSceneNode(int _faceCount, const MeshFace** _faces)
-    : renderNode(this)
+MeshFragSceneNode::MeshFragSceneNode(int faceCount_, const MeshFace** faces_)
+    : renderNode(*this)
+    , faceCount(faceCount_)
+    , faces(faces_)
+    , arrayCount(0)
 {
     int i, j, k;
 
-    assert ((_faceCount > 0) && (_faces != NULL));
-
-    // set the count
-    faces = _faces;
-    faceCount = _faceCount;
+    // This is semi-pointless, as assert is typically compiled out in production code.
+    // If protection is needed, a more/ robust solution should be provided
+    assert ((faceCount > 0) && (faces != NULL));
 
     // disable the plane
-    noPlane = true;
     static const float fakePlane[4] = {0.0f, 0.0f, 1.0f, 0.0f};
     setPlane(fakePlane);
 
@@ -278,7 +276,6 @@ MeshFragSceneNode::MeshFragSceneNode(int _faceCount, const MeshFace** _faces)
     setSphere(mySphere);
 
     // count the number of actual vertices
-    arrayCount = 0;
     for (i = 0; i < faceCount; i++)
     {
         const MeshFace* face = faces[i];
@@ -344,8 +341,6 @@ MeshFragSceneNode::MeshFragSceneNode(int _faceCount, const MeshFace** _faces)
     assert(arrayIndex == (arrayCount * 3));
 
     renderNode.init(); // setup the display list
-
-    return;
 }
 
 
@@ -355,10 +350,14 @@ MeshFragSceneNode::~MeshFragSceneNode()
     delete[] vertices;
     delete[] normals;
     delete[] texcoords;
-    return;
 }
 
 
+const GLfloat* MeshFragSceneNode::getPlane() const
+{
+    return NULL;
+}
+
 bool MeshFragSceneNode::cull(const ViewFrustum& frustum) const
 {
     // if the Visibility culler tells us that we're
@@ -404,7 +403,6 @@ void MeshFragSceneNode::addRenderNodes(SceneRenderer& renderer)
     const GLfloat* dyncol = getDynamicColor();
     if ((dyncol == NULL) || (dyncol[3] != 0.0f))
         renderer.addRenderNode(&renderNode, getWallGState());
-    return;
 }
 
 
@@ -416,7 +414,6 @@ void MeshFragSceneNode::addShadowNodes(SceneRenderer& renderer)
         if ((dyncol == NULL) || (dyncol[3] != 0.0f))
             renderer.addShadowNode(&renderNode);
     }
-    return;
 }
 
 
@@ -432,7 +429,6 @@ void MeshFragSceneNode::getRenderNodes(std::vector<RenderSet>& rnodes)
 {
     RenderSet rs = { &renderNode, getWallGState() };
     rnodes.push_back(rs);
-    return;
 }
 
 
