@@ -10,9 +10,6 @@
  * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
-// bzflag common header
-#include "common.h"
-
 // interface header
 #include "MeshPolySceneNode.h"
 
@@ -169,7 +166,7 @@ MeshPolySceneNode::MeshPolySceneNode(const float _plane[4],
 
     // choose axis to ignore (the one with the largest normal component)
     int ignoreAxis;
-    const GLfloat* normal = getPlane();
+    const auto normal = plane;
     if (fabsf(normal[0]) > fabsf(normal[1]))
     {
         if (fabsf(normal[0]) > fabsf(normal[2]))
@@ -286,8 +283,7 @@ bool MeshPolySceneNode::inAxisBox (const Extents& exts) const
     if (!extents.touches(exts))
         return false;
 
-    return testPolygonInAxisBox (getVertexCount(), getVertices(),
-                                 getPlane(), exts);
+    return testPolygonInAxisBox (getVertexCount(), getVertices(), plane, exts);
 }
 
 
