@@ -10,9 +10,6 @@
  * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
-// bzflag common header
-#include "common.h"
-
 // interface header
 #include "MeshSceneNode.h"
 
@@ -22,7 +19,6 @@
 #include <stdlib.h>
 
 // common implementation headers
-#include "vectors.h"
 #include "Extents.h"
 #include "Intersect.h"
 #include "TimeKeeper.h"
@@ -64,8 +60,6 @@ MeshSceneNode::MeshSceneNode(const MeshObstacle* _mesh)
     lodCount = 0;
     lods = NULL;
 
-    xformList = INVALID_GL_LIST_ID;
-
     if (mesh == NULL)
         return;
 
@@ -77,10 +71,6 @@ MeshSceneNode::MeshSceneNode(const MeshObstacle* _mesh)
     if (drawMgr == NULL)
         return;
 
-    // disable the plane
-    noPlane = true;
-    plane[0] = plane[1] = plane[2] = plane[3] = 0.0f;
-
     // setup the extents, sphere, and lengthPerPixel adjustment
     float lengthAdj = 1.0f;
     const Extents& diExts = drawInfo->getExtents();
@@ -188,7 +178,6 @@ MeshSceneNode::~MeshSceneNode()
     delete[] lods;
 
     OpenGLGState::unregisterContextInitializer(freeContext, initContext, this);
-    freeXFormList();
 
     return;
 }
@@ -212,25 +201,6 @@ inline int MeshSceneNode::calcNormalLod(const ViewFrustum& vf)
 }
 
 
-inline int MeshSceneNode::calcShadowLod(const ViewFrustum& vf)
-{
-    // FIXME: adjust for ray direction
-    const float* e = vf.getEye();
-    const float* s = getSphere();
-    const float* d = vf.getDirection();
-    const float dist = (d[0] * (s[0] - e[0])) +
-                       (d[1] * (s[1] - e[1])) +
-                       (d[2] * (s[2] - e[2]));
-    const float lengthPerPixel = dist * LodScale;
-    for (int i = (lodCount - 1); i > 0; i--)
-    {
-        if (lengthPerPixel > lodLengths[i])
-            return i;
-    }
-    return 0;
-}
-
-
 inline int MeshSceneNode::calcRadarLod()
 {
     for (int i = (radarCount - 1); i > 0; i--)
@@ -286,7 +256,7 @@ void MeshSceneNode::addRenderNodes(SceneRenderer& renderer)
 void MeshSceneNode::addShadowNodes(SceneRenderer& renderer)
 {
     const ViewFrustum& vf = renderer.getViewFrustum();
-    const int level = (lodCount == 1) ? 0 : calcShadowLod(vf);
+    const int level = (lodCount == 1) ? 0 : calcNormalLod(vf);
     LodNode& lod = lods[level];
     for (int i = 0; i < lod.count; i++)
     {
@@ -371,7 +341,7 @@ void MeshSceneNode::notifyStyleChange()
             if (!mat.needsSorting)
             {
                 setNode.node =
-                    new OpaqueRenderNode(drawMgr, &xformList, normalize,
+                    new OpaqueRenderNode(drawMgr, xformMatrix, normalize,
                                          mat.colorPtr, lod, set, extPtr,
                                          drawSet.triangleCount);
                 mat.animRepos = false;
@@ -383,7 +353,7 @@ void MeshSceneNode::notifyStyleChange()
                 if (xformTool != NULL)
                     xformTool->modifyVertex(setPos);
                 setNode.node =
-                    new AlphaGroupRenderNode(drawMgr, &xformList, normalize,
+                    new AlphaGroupRenderNode(drawMgr, xformMatrix, normalize,
                                              mat.colorPtr, lod, set, extPtr, setPos,
                                              drawSet.triangleCount);
                 if ((fabsf(drawSet.sphere[0]) > 0.001f) &&
@@ -399,7 +369,7 @@ void MeshSceneNode::notifyStyleChange()
             }
 
             setNode.radarNode =
-                new OpaqueRenderNode(drawMgr, &xformList, normalize,
+                new OpaqueRenderNode(drawMgr, xformMatrix, normalize,
                                      mat.colorPtr, lod, set, extPtr,
                                      drawSet.triangleCount);
         }
@@ -560,7 +530,7 @@ void MeshSceneNode::updateMaterial(MeshSceneNode::MeshMaterial* mat)
 
     // culling
     if (bzmat->getNoCulling())
-        builder.setCulling(GL_NONE);
+        builder.disableCulling();
 
     // generate the gstate
     gstate = builder.getState();
@@ -591,37 +561,11 @@ void MeshSceneNode::makeXFormList()
         };
 
         // oops, transpose
-        GLfloat matrix[16];
         for (int i = 0; i < 4; i++)
         {
             for (int j = 0; j < 4; j++)
-                matrix[(i*4)+j] = xformTool->getMatrix()[(j*4)+i];
+                xformMatrix[(i*4)+j] = xformTool->getMatrix()[(j*4)+i];
         }
-
-        xformList = glGenLists(1);
-        glNewList(xformList, GL_COMPILE);
-        {
-            glMultMatrixf(matrix);
-        }
-        glEndList();
-
-        error = glGetError();
-        if (error != GL_NO_ERROR)
-        {
-            logDebugMessage(0,"ERROR: MeshSceneNode::makeXFormList() failed: %i\n", error);
-            xformList = INVALID_GL_LIST_ID;
-        }
-    }
-    return;
-}
-
-
-void MeshSceneNode::freeXFormList()
-{
-    if (xformList != INVALID_GL_LIST_ID)
-    {
-        glDeleteLists(xformList, 1);
-        xformList = INVALID_GL_LIST_ID;
     }
     return;
 }
@@ -634,10 +578,8 @@ void MeshSceneNode::initContext(void* data)
 }
 
 
-void MeshSceneNode::freeContext(void* data)
+void MeshSceneNode::freeContext(void*)
 {
-    ((MeshSceneNode*)data)->freeXFormList();
-    return;
 }
 
 
