@@ -10,9 +10,6 @@
  * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
-// bzflag common header
-#include "common.h"
-
 // interface header
 #include "PolyWallSceneNode.h"
 
@@ -118,7 +115,7 @@ PolyWallSceneNode::PolyWallSceneNode(const GLfloat3Array& vertex,
 
     // choose axis to ignore (the one with the largest normal component)
     int ignoreAxis;
-    const GLfloat* normal = getPlane();
+    const auto normal = plane;
     if (fabsf(normal[0]) > fabsf(normal[1]))
         if (fabsf(normal[0]) > fabsf(normal[2]))
             ignoreAxis = 0;
