@@ -10,9 +10,6 @@
  * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
-// bzflag common header
-#include "common.h"
-
 // interface header
 #include "SphereSceneNode.h"
 
@@ -41,7 +38,7 @@ SphereSceneNode::SphereSceneNode(const GLfloat pos[3], GLfloat _radius)
     transparent = false;
 
     OpenGLGStateBuilder builder(gstate);
-    builder.setCulling(GL_NONE);
+    builder.disableCulling();
     gstate = builder.getState();
 
     setColor(1.0f, 1.0f, 1.0f, 1.0f);
@@ -363,8 +360,6 @@ void SphereLodSceneNode::SphereLodRenderNode::render()
     const GLfloat radius = sceneNode->radius;
     const GLfloat* sphere = sceneNode->getSphere();
 
-    static const GLdouble groundPlane[] = { 0.0, 0.0, 1.0, 0.0 };
-    glClipPlane(GL_CLIP_PLANE0, groundPlane);
     glEnable(GL_CLIP_PLANE0);
 
 #ifdef GL_VERSION_1_2
@@ -617,13 +612,10 @@ setBaseIndex(int _baseIndex)
 
 void            SphereBspSceneNode::SphereBspRenderNode::render()
 {
-    static const GLdouble groundPlane[] = { 0.0, 0.0, 1.0, 0.0 };
-
     int i, j;
     const GLfloat radius = sceneNode->radius;
     const GLfloat* sphere = sceneNode->getSphere();
 
-    glClipPlane(GL_CLIP_PLANE0, groundPlane);
     glEnable(GL_CLIP_PLANE0);
 
     glPushMatrix();
