@@ -9,11 +9,6 @@
  * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
  * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
-#define _NO_LIST_ID 0xffffffff
-
-// bzflag common headers
-#include "common.h"
-#include "global.h"
 
 // interface header
 #include "TankSceneNode.h"
@@ -32,6 +27,8 @@
 
 #include "TextureManager.h"
 
+#define _NO_LIST_ID 0xffffffff
+
 using namespace TankGeometryEnums;
 
 static const float MuzzleMaxX = 4.94f;
@@ -217,7 +214,7 @@ void TankSceneNode::notifyStyleChange()
 
 
     OpenGLGStateBuilder builder3(jumpJetsGState);
-    builder3.setCulling(GL_NONE);
+    builder3.disableCulling();
     builder3.setBlending(GL_SRC_ALPHA, GL_ONE);
     jumpJetsGState = builder3.getState();
 }
@@ -427,18 +424,19 @@ void TankSceneNode::setJumpJets(float scale)
 }
 
 
-void TankSceneNode::setClipPlane(const GLfloat* _plane)
+void TankSceneNode::setClipPlane(const float _plane[])
 {
-    if (!_plane)
-        clip = false;
-    else
-    {
-        clip = true;
-        clipPlane[0] = GLdouble(_plane[0]);
-        clipPlane[1] = GLdouble(_plane[1]);
-        clipPlane[2] = GLdouble(_plane[2]);
-        clipPlane[3] = GLdouble(_plane[3]);
-    }
+    clip = true;
+    clipPlane[0] = GLdouble(_plane[0]);
+    clipPlane[1] = GLdouble(_plane[1]);
+    clipPlane[2] = GLdouble(_plane[2]);
+    clipPlane[3] = GLdouble(_plane[3]);
+}
+
+
+void TankSceneNode::resetClipPlane()
+{
+    clip = false;
 }
 
 
@@ -576,7 +574,7 @@ TankIDLSceneNode::TankIDLSceneNode(const TankSceneNode* _tank) :
     setRadius(radius);
 
     OpenGLGStateBuilder builder(gstate);
-    builder.setCulling(GL_NONE);
+    builder.disableCulling();
     builder.setShading(GL_SMOOTH);
     builder.setBlending(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
     gstate = builder.getState();
@@ -940,8 +938,8 @@ void TankSceneNode::TankRenderNode::render()
 
     if (sceneNode->clip && !isShadow)
     {
-        glClipPlane(GL_CLIP_PLANE0, sceneNode->clipPlane);
-        glEnable(GL_CLIP_PLANE0);
+        glClipPlane(GL_CLIP_PLANE1, sceneNode->clipPlane);
+        glEnable(GL_CLIP_PLANE1);
     }
 
     const GLfloat* sphere = sceneNode->getSphere();
@@ -1049,7 +1047,7 @@ void TankSceneNode::TankRenderNode::render()
     if (!BZDBCache::blend && sceneNode->transparent)
         myStipple(0.5f);
     if (sceneNode->clip)
-        glDisable(GL_CLIP_PLANE0);
+        glDisable(GL_CLIP_PLANE1);
 
     return;
 }
@@ -1477,9 +1475,7 @@ void TankSceneNode::TankRenderNode::renderJumpJets()
     myColor4f(1.0f, 1.0f, 1.0f, 0.5f);
 
     // use a clip plane, because the ground has no depth
-    const GLdouble clip_plane[4] = {0.0, 0.0, 1.0, 0.0};
-    glClipPlane(GL_CLIP_PLANE1, clip_plane);
-    glEnable(GL_CLIP_PLANE1);
+    glEnable(GL_CLIP_PLANE0);
 
     sceneNode->jumpJetsGState.setState();
     glDepthMask(GL_FALSE);
@@ -1508,7 +1504,7 @@ void TankSceneNode::TankRenderNode::renderJumpJets()
     glDepthMask(GL_TRUE);
     sceneNode->gstate.setState();
 
-    glDisable(GL_CLIP_PLANE1);
+    glDisable(GL_CLIP_PLANE0);
 
     addTriangleCount(4);
 
