@@ -10,9 +10,6 @@
  * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
-// bzflag common header
-#include "common.h"
-
 // interface header
 #include "TriWallSceneNode.h"
 
@@ -229,9 +226,9 @@ TriWallSceneNode::TriWallSceneNode(const GLfloat base[3],
     uElements = 1;
     areas[level] = area;
     nodes[level++] = new Geometry(this, uElements, base, uEdge, vEdge,
-                                  getPlane(), uRepeats, vRepeats);
+                                  plane, uRepeats, vRepeats);
     shadowNode = new Geometry(this, uElements, base, uEdge, vEdge,
-                              getPlane(), uRepeats, vRepeats);
+                              plane, uRepeats, vRepeats);
     shadowNode->setStyle(0);
 
     // make remaining levels by doubling elements in each dimension
@@ -241,7 +238,7 @@ TriWallSceneNode::TriWallSceneNode(const GLfloat base[3],
         area *= 0.25f;
         areas[level] = area;
         nodes[level++] = new Geometry(this, uElements, base, uEdge, vEdge,
-                                      getPlane(), uRepeats, vRepeats);
+                                      plane, uRepeats, vRepeats);
     }
 
     // record extents info
@@ -324,7 +321,7 @@ bool            TriWallSceneNode::inAxisBox(const Extents& exts) const
     memcpy (vertices[1], nodes[0]->getVertex(1), sizeof(float[3]));
     memcpy (vertices[2], nodes[0]->getVertex(2), sizeof(float[3]));
 
-    return testPolygonInAxisBox (3, vertices, getPlane(), exts);
+    return testPolygonInAxisBox (3, vertices, plane, exts);
 }
 
 
