@@ -10,11 +10,7 @@
  * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
-// bzflag common header
-#include "common.h"
-
 // interface headers
-#include "Frustum.h"
 #include "ViewFrustum.h"
 
 // common implementation headers
