@@ -10,9 +10,6 @@
  * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
-// bzflag common header
-#include "common.h"
-
 // interface headers
 #include "WallSceneNode.h"
 #include "PolyWallSceneNode.h"
@@ -37,7 +34,6 @@ WallSceneNode::WallSceneNode() : numLODs(0),
     elementAreas(NULL),
     style(0)
 {
-    noPlane      = false;
     dynamicColor = NULL;
     color[3] = 1.0f;
     modulateColor[3] = 1.0f;
@@ -66,6 +62,11 @@ WallSceneNode::~WallSceneNode()
     delete[] elementAreas;
 }
 
+const GLfloat* WallSceneNode::getPlane() const
+{
+    return plane;
+}
+
 void            WallSceneNode::setNumLODs(int num, float* areas)
 {
     numLODs = num;
@@ -372,7 +373,7 @@ void            WallSceneNode::notifyStyleChange()
     if (alphaThreshold != 0.0f)
         builder.setAlphaFunc(GL_GEQUAL, alphaThreshold);
     if (noCulling)
-        builder.setCulling(GL_NONE);
+        builder.disableCulling();
     if (noSorting)
         builder.setNeedsSorting(false);
     if (wantSphereMap)
