@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993-2018 Tim Riker
+ * Copyright (c) 1993-2019 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -12,11 +12,10 @@
 
 /* interface header */
 #include "AresHandler.h"
-#include "Address.h"
 
 /* system implementation headers */
-#include <errno.h>
-#include <string.h>
+#include <cerrno>
+#include <cstring>
 
 bool AresHandler::globallyInited = false;
 
