@@ -654,7 +654,7 @@ void Teleporter::printOBJ(std::ostream& out, const std::string& UNUSED(indent))
         xtool.modifyNormal(norms[i]);
 
     out << "# OBJ - start tele" << std::endl;
-    out << "o bztele_" << getObjCounter() << std::endl;
+    out << "o bztele_" << name << std::endl;
 
     for (i = 0; i < 8; i++)
     {
@@ -691,8 +691,6 @@ void Teleporter::printOBJ(std::ostream& out, const std::string& UNUSED(indent))
 
     out << std::endl;
 
-    incObjCounter();
-
     return;
 }
 
