@@ -76,22 +76,19 @@ OpenGLTexture::Filter OpenGLTexture::maxFilter = Default;
 
 
 OpenGLTexture::OpenGLTexture(int _width, int _height, const GLvoid* pixels,
-                             Filter _filter, bool _repeat, int _internalFormat) :
+                             Filter _filter, bool _repeat) :
     width(_width), height(_height)
 {
-    alpha = false;
     repeat = _repeat;
-    internalFormat = _internalFormat;
     filter = _filter;
     list = INVALID_GL_TEXTURE_ID;
 
-    // get internal format if not provided
-    if (internalFormat == 0)
-        internalFormat = getBestFormat(width, height, pixels);
-
     // copy/scale the original texture image
     setupImage((const GLubyte*)pixels);
 
+    // get internal format
+    getBestFormat();
+
     // build and bind the GL texture
     initContext();
 
@@ -148,47 +145,64 @@ void OpenGLTexture::initContext()
     // compute next mipmap from current mipmap to save time.
     setFilter(filter);
     glBindTexture(GL_TEXTURE_2D, list);
-    gluBuild2DMipmaps(GL_TEXTURE_2D, internalFormat,
-                      scaledWidth, scaledHeight,
-                      GL_RGBA, GL_UNSIGNED_BYTE, image);
+    if (GLEW_VERSION_1_4)
+    {
+        glTexParameteri(GL_TEXTURE_2D, GL_GENERATE_MIPMAP, GL_TRUE);
+        glTexImage2D(GL_TEXTURE_2D, 0, internalFormat,
+                     scaledWidth, scaledHeight,
+                     0, internalFormat, GL_UNSIGNED_BYTE, image);
+    }
+    else
+    {
+        gluBuild2DMipmaps(GL_TEXTURE_2D, internalFormat,
+                          scaledWidth, scaledHeight,
+                          internalFormat, GL_UNSIGNED_BYTE, image);
+    }
     glBindTexture(GL_TEXTURE_2D, 0);
 
     return;
 }
 
 
-bool OpenGLTexture::setupImage(const GLubyte* pixels)
+void OpenGLTexture::setupImage(const GLubyte* pixels)
 {
-    // align to a 2^N value
-    scaledWidth = 1;
-    scaledHeight = 1;
-    while (scaledWidth < width)
-        scaledWidth <<= 1;
-    while (scaledHeight < height)
-        scaledHeight <<= 1;
+    if (GLEW_ARB_texture_non_power_of_two)
+    {
+        scaledWidth = width;
+        scaledHeight = height;
+        // Remove check of max size. I don't want to use gluScale if GL can handle non POT
+    }
+    else
+    {
+        // align to a 2^N value
+        scaledWidth = 1;
+        scaledHeight = 1;
+        while (scaledWidth < width)
+            scaledWidth <<= 1;
+        while (scaledHeight < height)
+            scaledHeight <<= 1;
 
-    // get maximum valid size for texture (boost to 2^m x 2^n)
-    GLint maxTextureSize;
-    glGetIntegerv(GL_MAX_TEXTURE_SIZE, &maxTextureSize);
+        // get maximum valid size for texture (boost to 2^m x 2^n)
+        GLint maxTextureSize;
+        glGetIntegerv(GL_MAX_TEXTURE_SIZE, &maxTextureSize);
 
-    // hard limit, some drivers have problems with sizes greater
-    // then this (espeically if you are using glTexSubImage2D)
-    const GLint dbMaxTexSize = BZDB.evalInt("maxTextureSize");
-    GLint bzMaxTexSize = 1;
-    // align the max size to a power of two  (wasteful)
-    while (bzMaxTexSize < dbMaxTexSize)
-        bzMaxTexSize <<= 1;
+        // hard limit, some drivers have problems with sizes greater
+        // then this (espeically if you are using glTexSubImage2D)
+        const GLint dbMaxTexSize = BZDB.evalInt("maxTextureSize");
+        GLint bzMaxTexSize = 1;
+        // align the max size to a power of two  (wasteful)
+        while (bzMaxTexSize < dbMaxTexSize)
+            bzMaxTexSize <<= 1;
 
-    if ((maxTextureSize < 0) || (maxTextureSize > bzMaxTexSize))
-        maxTextureSize = bzMaxTexSize;
+        if ((maxTextureSize < 0) || (maxTextureSize > bzMaxTexSize))
+            maxTextureSize = bzMaxTexSize;
 
-    // clamp to the maximum size
-    if (scaledWidth > maxTextureSize)
-        scaledWidth = maxTextureSize;
-    if (scaledHeight > maxTextureSize)
-        scaledHeight = maxTextureSize;
-
-    // NOTE: why these are 4-byte aligned is beyond me...
+        // clamp to the maximum size
+        if (scaledWidth > maxTextureSize)
+            scaledWidth = maxTextureSize;
+        if (scaledHeight > maxTextureSize)
+            scaledHeight = maxTextureSize;
+    }
 
     // copy the data into a 4-byte aligned buffer
     GLubyte* unaligned = new GLubyte[4 * width * height + 4];
@@ -215,30 +229,6 @@ bool OpenGLTexture::setupImage(const GLubyte* pixels)
     // set the image
     image = aligned;
     imageMemory = unaligned;
-
-    // note if internal format uses alpha
-    switch (internalFormat)
-    {
-    case GL_LUMINANCE_ALPHA:
-#if defined(GL_LUMINANCE4_ALPHA4)
-    case GL_LUMINANCE4_ALPHA4:
-#elif defined(GL_LUMINANCE4_ALPHA4_EXT)
-    case GL_LUMINANCE4_ALPHA4_EXT:
-#endif
-    case GL_RGBA:
-#if defined(GL_INTENSITY4)
-    case GL_INTENSITY4:
-#elif defined(GL_INTENSITY4_EXT)
-    case GL_INTENSITY4_EXT:
-#endif
-        alpha = true;
-        break;
-    default:
-        alpha = false;
-        break;
-    }
-
-    return true;
 }
 
 
@@ -341,90 +331,50 @@ void OpenGLTexture::bind()
 }
 
 
-int OpenGLTexture::getBestFormat(int _width, int _height, const GLvoid* pixels)
+void OpenGLTexture::getBestFormat()
 {
-    // see if all pixels are achromatic
-    const GLubyte* scan = (const GLubyte*)pixels;
-    const int size = _width * _height;
+    GLubyte* scan = image;
+    const int size = scaledWidth * scaledHeight;
     int i;
+    bool useLuminance = true;
+    alpha = false;
     for (i = 0; i < size; scan += 4, i++)
-        if (scan[0] != scan[1] || scan[0] != scan[2])
-            break;
-    const bool useLuminance = (i == size);
-
-    // see if all pixels are opaque
-    scan = (const GLubyte*)pixels;
-    for (i = 0; i < size; scan += 4, i++)
-        if (scan[3] != 0xff)
-            break;
-    const bool useAlpha = (i != size);
-
-    bool useIntensity = false;
-    if (useLuminance)
     {
-        scan = (const GLubyte*)pixels;
-        for (i = 0; i < size; scan += 4, i++)
-            if (scan[3] != scan[0])
-                break;
-        useIntensity = (i == size);
+        // see if all pixels are achromatic
+        if (scan[0] != scan[1] || scan[0] != scan[2])
+            useLuminance = false;
+        // see if all pixels are opaque
+        if (scan[3] != 0xff)
+            alpha = true;
+        if (!useLuminance && alpha)
+            break;
+    }
+
+    scan = image;
+    GLubyte* scanOut = image;
+    for (i = 0; i < size; i++)
+    {
+        *scanOut++ = *scan++;
+        if (useLuminance)
+        {
+            scan++;
+            scan++;
+        }
+        else
+        {
+            *scanOut++ = *scan++;
+            *scanOut++ = *scan++;
+        }
+        if (alpha)
+            *scanOut++ = *scan++;
+        else
+            scan++;
     }
-    if (useIntensity)
-        return GL_INTENSITY;
 
     // pick internal format
-    return (useLuminance ?
-            (useAlpha ? GL_LUMINANCE_ALPHA : GL_LUMINANCE) :
-            (useAlpha ? GL_RGBA : GL_RGB));
-}
-
-
-bool OpenGLTexture::getColorAverages(float rgba[4], bool factorAlpha) const
-{
-    if ((image == NULL) || (scaledWidth <= 0) || (scaledHeight <= 0))
-        return false;
-
-    factorAlpha = (factorAlpha && alpha);
-    const int channelCount = alpha ? 4 : 3;
-
-    // tally the values
-    s64 rgbaTally[4] = {0, 0, 0, 0};
-    for (int x = 0; x < scaledWidth; x++)
-    {
-        for (int y = 0; y < scaledHeight; y++)
-        {
-            for (int c = 0; c < channelCount; c++)
-            {
-                const int pixelBase = 4 * (x + (y * scaledWidth));
-                if (factorAlpha)
-                {
-                    const GLubyte alphaVal = image[pixelBase + 3];
-                    if (c == 3)
-                        rgbaTally[3] += alphaVal;
-                    else
-                        rgbaTally[c] += image[pixelBase + c] * alphaVal;
-                }
-                else
-                    rgbaTally[c] += image[pixelBase + c];
-            }
-        }
-    }
-
-    // calculate the alpha average
-    float maxTally = 255.0f * (scaledWidth * scaledHeight);
-    if (channelCount == 3)
-        rgba[3] = 1.0f;
-    else
-        rgba[3] = (float)rgbaTally[3] / maxTally;
-
-    // adjust the maxTally for alpha weighting
-    if (factorAlpha)
-        maxTally = maxTally * 255.0f;
-
-    // calcualte the color averages
-    for (int c = 0; c < 3; c++)
-        rgba[c] = (float)rgbaTally[c] / maxTally;
-
-    return true;
+    internalFormat = useLuminance ?
+                     (alpha ? GL_LUMINANCE_ALPHA : GL_LUMINANCE) :
+                     (alpha ? GL_RGBA : GL_RGB);
 }
 
 
