@@ -24,7 +24,7 @@ HWND SDLWindow::hwnd = NULL;
 SDLWindow::SDLWindow(const SDLDisplay* _display, SDLVisual*)
     : BzfWindow(_display), hasGamma(true), origGamma(-1.0f), lastGamma(1.0f),
       windowId(NULL), glContext(NULL), canGrabMouse(true), fullScreen(false),
-      base_width(640), base_height(480), min_width(-1), min_height(-1)
+      vsync(false), base_width(640), base_height(480), min_width(-1), min_height(-1)
 {
 }
 
@@ -172,10 +172,6 @@ bool SDLWindow::create(void)
     SDL_bool windowWasGrabbed = SDL_FALSE;
     if (windowId != NULL)
         windowWasGrabbed = SDL_GetWindowGrab(windowId);
-    int swapInterval = 0;
-    if (windowId != NULL)
-        if (glContext != NULL)
-            swapInterval = SDL_GL_GetSwapInterval() == 1;
 
     // if we have an existing identical window, go no further
     if (windowId != NULL)
@@ -240,59 +236,13 @@ bool SDLWindow::create(void)
     makeContext();
     makeCurrent();
 
-    SDL_GL_SetSwapInterval(swapInterval);
+    if(SDL_GL_SetSwapInterval(vsync ? -1 : 0) == -1 && vsync)
+        // no adaptive vsync; set regular vsync
+        SDL_GL_SetSwapInterval(1);
 
     // init opengl context
     OpenGLGState::initContext();
 
-    // workaround for SDL 2 bug on mac where toggling fullscreen will
-    // generate a resize event and mess up the window size/resolution
-    // (TODO: remove this if they ever fix it)
-    // bug report: https://bugzilla.libsdl.org/show_bug.cgi?id=3146
-#ifdef __APPLE__
-    if (fullScreen)
-        return true;
-
-    int currentDisplayIndex = SDL_GetWindowDisplayIndex(windowId);
-    if (currentDisplayIndex < 0)
-    {
-        printf("Unable to get current display index: %s\n", SDL_GetError());
-        return true;
-    }
-
-    SDL_DisplayMode desktopDisplayMode;
-    if (SDL_GetDesktopDisplayMode(currentDisplayIndex, &desktopDisplayMode) < 0)
-    {
-        printf("Unable to get desktop display mode: %s\n", SDL_GetError());
-        return true;
-    }
-
-    std::vector<SDL_Event> eventStack;
-    SDL_Event thisEvent;
-
-    // pop off all the events except a resize event
-    while (SDL_PollEvent(&thisEvent))
-    {
-        if (thisEvent.type == SDL_WINDOWEVENT && thisEvent.window.event == SDL_WINDOWEVENT_RESIZED)
-        {
-            // switching from "native" fullscreen to SDL fullscreen and then going back to
-            // windowed mode will generate a legitimate resize event, so add it back
-            if (thisEvent.window.data1 != desktopDisplayMode.w || thisEvent.window.data2 != desktopDisplayMode.h)
-                eventStack.push_back(thisEvent);
-        }
-        else
-            eventStack.push_back(thisEvent);
-    }
-
-    // push them back on in the same order
-    while (eventStack.size() > 0)
-    {
-        SDL_PushEvent(&eventStack[0]);
-
-        eventStack.erase(eventStack.begin());
-    }
-#endif //__APPLE__
-
     return true;
 }
 
@@ -314,7 +264,13 @@ void SDLWindow::makeContext()
 
 void SDLWindow::setVerticalSync(bool setting)
 {
-    SDL_GL_SetSwapInterval(setting ? 1 : 0);
+    vsync = setting;
+
+    if (windowId != NULL)
+        if (glContext != NULL)
+            if(SDL_GL_SetSwapInterval(vsync ? -1 : 0) == -1 && vsync)
+                // no adaptive vsync; set regular vsync
+                SDL_GL_SetSwapInterval(1);
 }
 
 void SDLWindow::setMinSize(int width, int height)
